@@ -6,8 +6,6 @@
  */
 
 use Drupal\Core\DependencyInjection\ContainerNotInitializedException;
-use Drupal\Core\Messenger\LegacyMessenger;
-use Drupal\Core\Url;
 use Symfony\Component\DependencyInjection\ContainerInterface;
 
 /**
@@ -82,7 +80,7 @@ class Drupal {
   /**
    * The current system version.
    */
-  const VERSION = '8.8.5';
+  const VERSION = '9.0.0';
 
   /**
    * Core API compatibility.
@@ -178,7 +176,7 @@ class Drupal {
    * @return string
    */
   public static function root() {
-    return static::getContainer()->get('app.root');
+    return static::getContainer()->getParameter('app.root');
   }
 
   /**
@@ -264,23 +262,6 @@ class Drupal {
     return static::getContainer()->get('current_user');
   }
 
-  /**
-   * Retrieves the entity manager service.
-   *
-   * @return \Drupal\Core\Entity\EntityManagerInterface
-   *   The entity manager service.
-   *
-   * @deprecated in drupal:8.0.0 and is removed from drupal:9.0.0.
-   *   Use \Drupal::entityTypeManager() instead in most cases. If the needed
-   *   method is not on \Drupal\Core\Entity\EntityTypeManagerInterface, see the
-   *   deprecated \Drupal\Core\Entity\EntityManager to find the
-   *   correct interface or service.
-   */
-  public static function entityManager() {
-    @trigger_error("\Drupal::entityManager() is deprecated in Drupal 8.0.0 and will be removed before Drupal 9.0.0. Use \Drupal::entityTypeManager() instead in most cases. If the needed method is not on \Drupal\Core\Entity\EntityTypeManagerInterface, see the deprecated \Drupal\Core\Entity\EntityManager to find the correct interface or service. See https://www.drupal.org/node/2549139", E_USER_DEPRECATED);
-    return static::getContainer()->get('entity.manager');
-  }
-
   /**
    * Retrieves the entity type manager.
    *
@@ -552,45 +533,6 @@ class Drupal {
     return static::getContainer()->get('url_generator');
   }
 
-  /**
-   * Generates a URL string for a specific route based on the given parameters.
-   *
-   * This method is a convenience wrapper for generating URL strings for URLs
-   * that have Drupal routes (that is, most pages generated by Drupal) using
-   * the \Drupal\Core\Url object. See \Drupal\Core\Url::fromRoute() for
-   * detailed documentation. For non-routed local URIs relative to
-   * the base path (like robots.txt) use Url::fromUri()->toString() with the
-   * base: scheme.
-   *
-   * @param string $route_name
-   *   The name of the route.
-   * @param array $route_parameters
-   *   (optional) An associative array of parameter names and values.
-   * @param array $options
-   *   (optional) An associative array of additional options.
-   * @param bool $collect_bubbleable_metadata
-   *   (optional) Defaults to FALSE. When TRUE, both the generated URL and its
-   *   associated bubbleable metadata are returned.
-   *
-   * @return string|\Drupal\Core\GeneratedUrl
-   *   A string containing a URL to the given path.
-   *   When $collect_bubbleable_metadata is TRUE, a GeneratedUrl object is
-   *   returned, containing the generated URL plus bubbleable metadata.
-   *
-   * @see \Drupal\Core\Routing\UrlGeneratorInterface::generateFromRoute()
-   * @see \Drupal\Core\Url
-   * @see \Drupal\Core\Url::fromRoute()
-   * @see \Drupal\Core\Url::fromUri()
-   *
-   * @deprecated in drupal:8.0.0 and is removed from drupal:9.0.0.
-   *   Instead create a \Drupal\Core\Url object directly, for example using
-   *   Url::fromRoute().
-   */
-  public static function url($route_name, $route_parameters = [], $options = [], $collect_bubbleable_metadata = FALSE) {
-    @trigger_error('Drupal::url() is deprecated as of Drupal 8.0.x, will be removed before Drupal 9.0.0. Instead create a \Drupal\Core\Url object directly, for example using Url::fromRoute()', E_USER_DEPRECATED);
-    return static::getContainer()->get('url_generator')->generateFromRoute($route_name, $route_parameters, $options, $collect_bubbleable_metadata);
-  }
-
   /**
    * Returns the link generator service.
    *
@@ -600,33 +542,6 @@ class Drupal {
     return static::getContainer()->get('link_generator');
   }
 
-  /**
-   * Renders a link with a given link text and Url object.
-   *
-   * This method is a convenience wrapper for the link generator service's
-   * generate() method.
-   *
-   * @param string $text
-   *   The link text for the anchor tag.
-   * @param \Drupal\Core\Url $url
-   *   The URL object used for the link.
-   *
-   * @return \Drupal\Core\GeneratedLink
-   *   A GeneratedLink object containing a link to the given route and
-   *   parameters and bubbleable metadata.
-   *
-   * @deprecated in drupal:8.0.0 and is removed from drupal:9.0.0. Use
-   * \Drupal\Core\Link::fromTextAndUrl() instead.
-   *
-   * @see https://www.drupal.org/node/2614344
-   * @see \Drupal\Core\Utility\LinkGeneratorInterface::generate()
-   * @see \Drupal\Core\Url
-   */
-  public static function l($text, Url $url) {
-    @trigger_error('\Drupal::l() is deprecated in drupal:8.0.0 and is removed from drupal:9.0.0. Use \Drupal\Core\Link::fromTextAndUrl() instead. See https://www.drupal.org/node/2614344', E_USER_DEPRECATED);
-    return static::getContainer()->get('link_generator')->generate($text, $url);
-  }
-
   /**
    * Returns the string translation service.
    *
@@ -783,9 +698,7 @@ class Drupal {
    *   The messenger.
    */
   public static function messenger() {
-    // @todo Replace with service once LegacyMessenger is removed in 9.0.0.
-    // @see https://www.drupal.org/node/2928994
-    return new LegacyMessenger();
+    return static::getContainer()->get('messenger');
   }
 
 }
