@@ -38,6 +38,9 @@ class Datetime extends DateElementBase {
     }
 
     $class = get_class($this);
+
+    // Note that since this information is cached, the #date_timezone property
+    // is not set here, as this needs to vary potentially by-user.
     return [
       '#input' => TRUE,
       '#element_validate' => [
@@ -61,7 +64,6 @@ class Datetime extends DateElementBase {
       '#date_time_callbacks' => [],
       '#date_year_range' => '1900:2050',
       '#date_increment' => 1,
-      '#date_timezone' => date_default_timezone_get(),
     ];
   }
 
@@ -69,6 +71,8 @@ class Datetime extends DateElementBase {
    * {@inheritdoc}
    */
   public static function valueCallback(&$element, $input, FormStateInterface $form_state) {
+    $element += ['#date_timezone' => date_default_timezone_get()];
+
     if ($input !== FALSE) {
       $date_input = $element['#date_date_element'] != 'none' && !empty($input['date']) ? $input['date'] : '';
       $time_input = $element['#date_time_element'] != 'none' && !empty($input['time']) ? $input['time'] : '';
@@ -159,7 +163,6 @@ class Datetime extends DateElementBase {
    *     - text: No HTML5 element, use a normal text field.
    *     - none: Do not display a date element.
    *   - #date_date_callbacks: Array of optional callbacks for the date element.
-   *     Can be used to add a jQuery datepicker.
    *   - #date_time_element: The time element. Options are:
    *     - time: Use a HTML5 time element type.
    *     - text: No HTML5 element, use a normal text field.
@@ -179,15 +182,14 @@ class Datetime extends DateElementBase {
    *     earliest year and the second the latest year in the range. A year
    *     in either position means that specific year. A +/- value describes a
    *     dynamic value that is that many years earlier or later than the current
-   *     year at the time the form is displayed. Used in jQueryUI datepicker year
-   *     range and HTML5 min/max date settings. Defaults to '1900:2050'.
+   *     year at the time the form is displayed. Used in HTML5 min/max date
+   *     settings. Defaults to '1900:2050'.
    *   - #date_increment: The interval (step) to use when incrementing or
    *     decrementing time, in seconds. For example, if this value is set to 30,
    *     time increases (or decreases) in steps of 30 seconds (00:00:00,
    *     00:00:30, 00:01:00, and so on.) If this value is a multiple of 60, the
    *     "seconds"-component will not be shown in the input. Used for HTML5 step
-   *     values and jQueryUI datepicker settings. Defaults to 1 to show every
-   *     second.
+   *     values. Defaults to 1 to show every second.
    *   - #date_timezone: The Time Zone Identifier (TZID) to use when displaying
    *     or interpreting dates, i.e: 'Asia/Kolkata'. Defaults to the value
    *     returned by date_default_timezone_get().
