@@ -16,7 +16,7 @@ class SpecialAttributesRouteSubscriber extends RouteSubscriberBase {
    * {@inheritdoc}
    */
   protected function alterRoutes(RouteCollection $collection) {
-    $special_variables = array(
+    $special_variables = [
       'system_path',
       '_legacy',
       '_raw_variables',
@@ -25,7 +25,7 @@ class SpecialAttributesRouteSubscriber extends RouteSubscriberBase {
       '_content',
       '_controller',
       '_form',
-    );
+    ];
     foreach ($collection->all() as $name => $route) {
       if ($not_allowed_variables = array_intersect($route->compile()->getVariables(), $special_variables)) {
         $reserved = implode(', ', $not_allowed_variables);
