@@ -47,10 +47,12 @@ class ThemeExtensionList extends ExtensionList {
       'comment_user_verification',
     ],
     'screenshot' => 'screenshot.png',
+    'version' => NULL,
     'php' => DRUPAL_MINIMUM_PHP,
     'libraries' => [],
     'libraries_extend' => [],
     'libraries_override' => [],
+    'dependencies' => [],
   ];
 
   /**
@@ -140,6 +142,22 @@ class ThemeExtensionList extends ExtensionList {
     // sub-themes.
     $this->fillInSubThemeData($themes, $sub_themes);
 
+    foreach ($themes as $key => $theme) {
+      // After $theme is processed by buildModuleDependencies(), there can be a
+      // `$theme->requires` array containing both module and base theme
+      // dependencies. The module dependencies are copied to their own property
+      // so they are available to operations specific to module dependencies.
+      if (isset($theme->requires)) {
+        $theme->module_dependencies = array_diff_key($theme->requires, $themes);
+      }
+      else {
+        // Even if no requirements are specified, the theme installation process
+        // expects the presence of the `requires` and `module_dependencies`
+        // properties, so they should be initialized here as empty arrays.
+        $theme->requires = [];
+        $theme->module_dependencies = [];
+      }
+    }
     return $themes;
   }
 
@@ -247,24 +265,12 @@ class ThemeExtensionList extends ExtensionList {
   protected function createExtensionInfo(Extension $extension) {
     $info = parent::createExtensionInfo($extension);
 
-    // In the past, Drupal used to default to the `stable` theme as the base
-    // theme. Explicitly opting out by specifying `base theme: false` was (and
-    // still is) possible. However, defaulting to `base theme: stable` prevents
-    // automatic updates to the next major version of Drupal, since each major
-    // version may have a different version of "the stable theme", for example:
-    // - for Drupal 8: `stable`
-    // - for Drupal 9: `stable9`
-    // - for Drupal 10: `stable10`
-    // - et cetera
-    // It is impossible to reliably determine which should be used by default,
-    // hence we now require the base theme to be explicitly specified.
     if (!isset($info['base theme'])) {
-      @trigger_error(sprintf('There is no `base theme` property specified in the %s.info.yml file. The optionality of the `base theme` property is deprecated in drupal:8.8.0 and is removed from drupal:9.0.0. All Drupal 8 themes must add `base theme: stable` to their *.info.yml file for them to continue to work as-is in future versions of Drupal. Drupal 9 requires the `base theme` property to be specified. See https://www.drupal.org/node/3066038', $extension->getName()), E_USER_DEPRECATED);
-      $info['base theme'] = 'stable';
+      throw new InfoParserException('Missing required key (base_theme) in ' . $extension->getExtensionPathname() . '/' . $extension->getExtensionFilename());
     }
 
-    // Remove the default Stable base theme when 'base theme: false' is set in
-    // a theme .info.yml file.
+    // Remove the base theme when 'base theme: false' is set in a theme
+    // .info.yml file.
     if ($info['base theme'] === FALSE) {
       unset($info['base theme']);
     }
