@@ -10,7 +10,7 @@ namespace Drupal\Core\Field\Plugin\Field\FieldType;
  *   label = @Translation("Created"),
  *   description = @Translation("An entity field containing a UNIX timestamp of when the entity has been created."),
  *   no_ui = TRUE,
- *   default_widget = "datetime_default",
+ *   default_widget = "datetime_timestamp",
  *   default_formatter = "timestamp"
  * )
  */
@@ -22,7 +22,7 @@ class CreatedItem extends TimestampItem {
   public function applyDefaultValue($notify = TRUE) {
     parent::applyDefaultValue($notify);
     // Created fields default to the current timestamp.
-    $this->setValue(array('value' => REQUEST_TIME), $notify);
+    $this->setValue(['value' => REQUEST_TIME], $notify);
     return $this;
   }
 
