@@ -64,12 +64,7 @@ class MapItem extends FieldItemBase {
         $values = $values->getValue();
       }
       else {
-        if (version_compare(PHP_VERSION, '7.0.0', '>=')) {
-          $values = unserialize($values, ['allowed_classes' => FALSE]);
-        }
-        else {
-          $values = unserialize($values);
-        }
+        $values = unserialize($values, ['allowed_classes' => FALSE]);
       }
     }
 
