@@ -66,13 +66,6 @@ trait TestSetupTrait {
    */
   protected $privateFilesDirectory;
 
-  /**
-   * The original installation profile.
-   *
-   * @var string
-   */
-  protected $originalProfile;
-
   /**
    * Set to TRUE to strict check all configuration saved.
    *
