@@ -210,7 +210,7 @@
         // Clone the table header so it inherits original jQuery properties.
         const $stickyHeader = this.$originalHeader.clone(true);
         // Hide the table to avoid a flash of the header clone upon page load.
-        this.$stickyTable = $('<table class="sticky-header"/>')
+        this.$stickyTable = $('<table class="sticky-header"></table>')
           .css({
             visibility: 'hidden',
             position: 'fixed',
@@ -326,4 +326,4 @@
 
   // Expose constructor in the public space.
   Drupal.TableHeader = TableHeader;
-})(jQuery, Drupal, window.parent.Drupal.displace);
+})(jQuery, Drupal, window.Drupal.displace);
