@@ -41,7 +41,7 @@ class UpdateFeedItemTest extends AggregatorTestBase {
     ];
 
     $this->drupalGet($edit['url[0][value]']);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     $this->drupalPostForm('aggregator/sources/add', $edit, t('Save'));
     $this->assertText(t('The feed @name has been added.', ['@name' => $edit['title[0][value]']]), new FormattableMarkup('The feed @name has been added.', ['@name' => $edit['title[0][value]']]));
@@ -75,7 +75,7 @@ class UpdateFeedItemTest extends AggregatorTestBase {
     $this->enableTestPlugins();
     $this->container->get('module_installer')->uninstall(['aggregator_test']);
     $this->updateFeedItems($feed);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
   }
 
 }
