@@ -23,7 +23,12 @@ class BasicAuthTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['basic_auth', 'router_test', 'locale', 'basic_auth_test'];
+  protected static $modules = [
+    'basic_auth',
+    'router_test',
+    'locale',
+    'basic_auth_test',
+  ];
 
   /**
    * {@inheritdoc}
@@ -42,30 +47,37 @@ class BasicAuthTest extends BrowserTestBase {
     $account = $this->drupalCreateUser();
     $url = Url::fromRoute('router_test.11');
 
+    // Ensure we can log in with valid authentication details.
     $this->basicAuthGet($url, $account->getAccountName(), $account->pass_raw);
     $this->assertText($account->getAccountName(), 'Account name is displayed.');
-    $this->assertResponse('200', 'HTTP response is OK');
+    $this->assertSession()->statusCodeEquals(200);
     $this->mink->resetSessions();
     $this->assertNull($this->drupalGetHeader('X-Drupal-Cache'));
-    $this->assertIdentical(strpos($this->drupalGetHeader('Cache-Control'), 'public'), FALSE, 'Cache-Control is not set to public');
+    // Check that Cache-Control is not set to public.
+    $this->assertSession()->responseHeaderNotContains('Cache-Control', 'public');
 
+    // Ensure that invalid authentication details give access denied.
     $this->basicAuthGet($url, $account->getAccountName(), $this->randomMachineName());
     $this->assertNoText($account->getAccountName(), 'Bad basic auth credentials do not authenticate the user.');
-    $this->assertResponse('403', 'Access is not granted.');
+    $this->assertSession()->statusCodeEquals(403);
     $this->mink->resetSessions();
 
+    // Ensure that the user is prompted to authenticate if they are not yet
+    // authenticated and the route only allows basic auth.
     $this->drupalGet($url);
     $this->assertEqual($this->drupalGetHeader('WWW-Authenticate'), new FormattableMarkup('Basic realm="@realm"', ['@realm' => \Drupal::config('system.site')->get('name')]));
-    $this->assertResponse('401', 'Not authenticated on the route that allows only basic_auth. Prompt to authenticate received.');
+    $this->assertSession()->statusCodeEquals(401);
 
+    // Ensure that a route without basic auth defined doesn't prompt for auth.
     $this->drupalGet('admin');
-    $this->assertResponse('403', 'No authentication prompt for routes not explicitly defining authentication providers.');
+    $this->assertSession()->statusCodeEquals(403);
 
     $account = $this->drupalCreateUser(['access administration pages']);
 
+    // Ensure that a route without basic auth defined doesn't allow login.
     $this->basicAuthGet(Url::fromRoute('system.admin'), $account->getAccountName(), $account->pass_raw);
     $this->assertNoLink('Log out', 'User is not logged in');
-    $this->assertResponse('403', 'No basic authentication for routes not explicitly defining authentication providers.');
+    $this->assertSession()->statusCodeEquals(403);
     $this->mink->resetSessions();
 
     // Ensure that pages already in the page cache aren't returned from page
@@ -75,7 +87,8 @@ class BasicAuthTest extends BrowserTestBase {
     $this->assertEqual($this->drupalGetHeader('X-Drupal-Cache'), 'MISS');
     $this->basicAuthGet($url, $account->getAccountName(), $account->pass_raw);
     $this->assertNull($this->drupalGetHeader('X-Drupal-Cache'));
-    $this->assertIdentical(strpos($this->drupalGetHeader('Cache-Control'), 'public'), FALSE, 'No page cache response when requesting a cached page with basic auth credentials.');
+    // Check that Cache-Control is not set to public.
+    $this->assertSession()->responseHeaderNotContains('Cache-Control', 'public');
   }
 
   /**
@@ -100,7 +113,7 @@ class BasicAuthTest extends BrowserTestBase {
 
     // IP limit has reached to its limit. Even valid user credentials will fail.
     $this->basicAuthGet($url, $user->getAccountName(), $user->pass_raw);
-    $this->assertResponse('403', 'Access is blocked because of IP based flood prevention.');
+    $this->assertSession()->statusCodeEquals(403);
   }
 
   /**
@@ -124,7 +137,7 @@ class BasicAuthTest extends BrowserTestBase {
 
     // A successful login will reset the per-user flood control count.
     $this->basicAuthGet($url, $user->getAccountName(), $user->pass_raw);
-    $this->assertResponse('200', 'Per user flood prevention gets reset on a successful login.');
+    $this->assertSession()->statusCodeEquals(200);
 
     // Try 2 failed logins for a user. They will trigger flood control.
     for ($i = 0; $i < 2; $i++) {
@@ -133,12 +146,12 @@ class BasicAuthTest extends BrowserTestBase {
 
     // Now the user account is blocked.
     $this->basicAuthGet($url, $user->getAccountName(), $user->pass_raw);
-    $this->assertResponse('403', 'The user account is blocked due to per user flood prevention.');
+    $this->assertSession()->statusCodeEquals(403);
 
     // Try one successful attempt for a different user, it should not trigger
     // any flood control.
     $this->basicAuthGet($url, $user2->getAccountName(), $user2->pass_raw);
-    $this->assertResponse('200', 'Per user flood prevention does not block access for other users.');
+    $this->assertSession()->statusCodeEquals(200);
   }
 
   /**
@@ -153,7 +166,7 @@ class BasicAuthTest extends BrowserTestBase {
 
     $this->basicAuthGet($url, $account->getAccountName(), $account->pass_raw);
     $this->assertText($account->getAccountName(), 'Account name is displayed.');
-    $this->assertResponse('200', 'HTTP response is OK');
+    $this->assertSession()->statusCodeEquals(200);
   }
 
   /**
@@ -165,24 +178,24 @@ class BasicAuthTest extends BrowserTestBase {
 
     // Case when no credentials are passed.
     $this->drupalGet($url);
-    $this->assertResponse('401', 'The user is blocked when no credentials are passed.');
+    $this->assertSession()->statusCodeEquals(401);
     $this->assertNoText('Exception', "No raw exception is displayed on the page.");
     $this->assertText('Please log in to access this page.', "A user friendly access unauthorized message is displayed.");
 
     // Case when empty credentials are passed.
     $this->basicAuthGet($url, NULL, NULL);
-    $this->assertResponse('403', 'The user is blocked when empty credentials are passed.');
+    $this->assertSession()->statusCodeEquals(403);
     $this->assertText('Access denied', "A user friendly access denied message is displayed");
 
     // Case when wrong credentials are passed.
     $this->basicAuthGet($url, $account->getAccountName(), $this->randomMachineName());
-    $this->assertResponse('403', 'The user is blocked when wrong credentials are passed.');
+    $this->assertSession()->statusCodeEquals(403);
     $this->assertText('Access denied', "A user friendly access denied message is displayed");
 
     // Case when correct credentials but hasn't access to the route.
     $url = Url::fromRoute('router_test.15');
     $this->basicAuthGet($url, $account->getAccountName(), $account->pass_raw);
-    $this->assertResponse('403', 'The used authentication method is not allowed on this route.');
+    $this->assertSession()->statusCodeEquals(403);
     $this->assertText('Access denied', "A user friendly access denied message is displayed");
   }
 
@@ -234,19 +247,19 @@ class BasicAuthTest extends BrowserTestBase {
    */
   public function testControllerNotCalledBeforeAuth() {
     $this->drupalGet('/basic_auth_test/state/modify');
-    $this->assertResponse(401);
+    $this->assertSession()->statusCodeEquals(401);
     $this->drupalGet('/basic_auth_test/state/read');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw('nope');
 
     $account = $this->drupalCreateUser();
     $this->basicAuthGet('/basic_auth_test/state/modify', $account->getAccountName(), $account->pass_raw);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw('Done');
 
     $this->mink->resetSessions();
     $this->drupalGet('/basic_auth_test/state/read');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw('yep');
   }
 
