@@ -3,7 +3,6 @@
 namespace Drupal\block;
 
 use Drupal\Component\Utility\Html;
-use Drupal\Core\DependencyInjection\DeprecatedServicePropertyTrait;
 use Drupal\Core\Plugin\PluginFormFactoryInterface;
 use Drupal\Core\Block\BlockPluginInterface;
 use Drupal\Core\Entity\EntityForm;
@@ -24,12 +23,6 @@ use Symfony\Component\DependencyInjection\ContainerInterface;
  * @internal
  */
 class BlockForm extends EntityForm {
-  use DeprecatedServicePropertyTrait;
-
-  /**
-   * {@inheritdoc}
-   */
-  protected $deprecatedProperties = ['entityManager' => 'entity.manager'];
 
   /**
    * The block entity.
@@ -84,7 +77,7 @@ class BlockForm extends EntityForm {
    * Constructs a BlockForm object.
    *
    * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
-   *   The entity manager.
+   *   The entity type manager.
    * @param \Drupal\Core\Executable\ExecutableManagerInterface $manager
    *   The ConditionManager for building the visibility UI.
    * @param \Drupal\Core\Plugin\Context\ContextRepositoryInterface $context_repository
@@ -173,7 +166,7 @@ class BlockForm extends EntityForm {
       $form['theme'] = [
         '#type' => 'select',
         '#options' => $theme_options,
-        '#title' => t('Theme'),
+        '#title' => $this->t('Theme'),
         '#default_value' => $theme,
         '#ajax' => [
           'callback' => '::themeSwitch',
@@ -384,16 +377,6 @@ class BlockForm extends EntityForm {
       $condition = $form_state->get(['conditions', $condition_id]);
       $condition->submitConfigurationForm($form['visibility'][$condition_id], SubformState::createForSubform($form['visibility'][$condition_id], $form, $form_state));
 
-      // Setting conditions' context mappings is the plugins' responsibility.
-      // This code exists for backwards compatibility, because
-      // \Drupal\Core\Condition\ConditionPluginBase::submitConfigurationForm()
-      // did not set its own mappings until Drupal 8.2
-      // @todo Remove the code that sets context mappings in Drupal 9.0.0.
-      if ($condition instanceof ContextAwarePluginInterface) {
-        $context_mapping = isset($values['context_mapping']) ? $values['context_mapping'] : [];
-        $condition->setContextMapping($context_mapping);
-      }
-
       $condition_configuration = $condition->getConfiguration();
       // Update the visibility conditions on the block.
       $this->entity->getVisibilityConditions()->addInstanceId($condition_id, $condition_configuration);
