@@ -16,7 +16,7 @@ class BlockDemoTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['block'];
+  protected static $modules = ['block'];
 
   /**
    * {@inheritdoc}
@@ -35,7 +35,7 @@ class BlockDemoTest extends BrowserTestBase {
     $config = $this->container->get('config.factory')->get('system.theme');
     $default_theme = $config->get('default');
     $this->drupalGet('admin/structure/block/demo/' . $default_theme);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertLinkByHref('admin/structure/block');
     $this->assertNoLinkByHref('admin/structure/block/list/' . $default_theme);
 
@@ -55,14 +55,14 @@ class BlockDemoTest extends BrowserTestBase {
       $this->container->get('theme_installer')->install([$theme]);
       // Confirm access to the block demo page for the theme.
       $this->drupalGet('admin/structure/block/demo/' . $theme);
-      $this->assertResponse(200);
+      $this->assertSession()->statusCodeEquals(200);
       // Confirm existence of link for "Exit block region demonstration".
       $this->assertLinkByHref('admin/structure/block/list/' . $theme);
     }
 
     // Confirm access to the block demo page is denied for an invalid theme.
     $this->drupalGet('admin/structure/block/demo/invalid_theme');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
   }
 
 }
