@@ -19,7 +19,12 @@ class BlockUiTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['block', 'block_test', 'help', 'condition_test'];
+  protected static $modules = [
+    'block',
+    'block_test',
+    'help',
+    'condition_test',
+  ];
 
   /**
    * {@inheritdoc}
@@ -47,7 +52,7 @@ class BlockUiTest extends BrowserTestBase {
    */
   protected $adminUser;
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     // Create and log in an administrative user.
     $this->adminUser = $this->drupalCreateUser([
@@ -89,13 +94,15 @@ class BlockUiTest extends BrowserTestBase {
     $elements = $this->xpath('//div[contains(@class, "region-highlighted")]/div[contains(@class, "block-region") and contains(text(), :title)]', [':title' => 'Highlighted']);
     $this->assertTrue(!empty($elements), 'Block demo regions are shown.');
 
+    // Ensure that other themes can use the block demo page.
     \Drupal::service('theme_installer')->install(['test_theme']);
     $this->drupalGet('admin/structure/block/demo/test_theme');
     $this->assertEscaped('<strong>Test theme</strong>');
 
+    // Ensure that a hidden theme cannot use the block demo page.
     \Drupal::service('theme_installer')->install(['stable']);
     $this->drupalGet('admin/structure/block/demo/stable');
-    $this->assertResponse(404, 'Hidden themes that are not the default theme are not supported by the block demo screen');
+    $this->assertSession()->statusCodeEquals(404);
   }
 
   /**
@@ -154,16 +161,19 @@ class BlockUiTest extends BrowserTestBase {
     $this->assertLink($theme_handler->getName('stark'));
     $this->assertNoLink($theme_handler->getName('stable'));
 
+    // Ensure that a hidden theme cannot use the block demo page.
     $this->drupalGet('admin/structure/block/list/stable');
-    $this->assertResponse(404, 'Placing blocks through UI is not possible for a hidden base theme.');
+    $this->assertSession()->statusCodeEquals(404);
 
+    // Ensure that a hidden theme set as the admin theme can use the block demo
+    // page.
     \Drupal::configFactory()->getEditable('system.theme')->set('admin', 'stable')->save();
     \Drupal::service('router.builder')->rebuildIfNeeded();
     $this->drupalPlaceBlock('local_tasks_block', ['region' => 'header', 'theme' => 'stable']);
     $this->drupalGet('admin/structure/block');
     $this->assertLink($theme_handler->getName('stable'));
     $this->drupalGet('admin/structure/block/list/stable');
-    $this->assertResponse(200, 'Placing blocks through UI is possible for a hidden base theme that is the admin theme.');
+    $this->assertSession()->statusCodeEquals(200);
   }
 
   /**
@@ -372,9 +382,9 @@ class BlockUiTest extends BrowserTestBase {
     $block = reset($this->blocks);
     // Ensure that the enable and disable routes are protected.
     $this->drupalGet('admin/structure/block/manage/' . $block->id() . '/disable');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
     $this->drupalGet('admin/structure/block/manage/' . $block->id() . '/enable');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
   }
 
 }
