@@ -67,7 +67,7 @@ class BlockFormTest extends UnitTestCase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->conditionManager = $this->createMock('Drupal\Core\Executable\ExecutableManagerInterface');
