@@ -2,9 +2,7 @@
 
 namespace Drupal\Tests\block_content\Functional;
 
-use Drupal\block_content\Entity\BlockContent;
 use Drupal\block_content\Entity\BlockContentType;
-use Drupal\Core\Database\Database;
 use Drupal\Tests\content_translation\Functional\ContentTranslationUITestBase;
 
 /**
@@ -19,7 +17,7 @@ class BlockContentTranslationUITest extends ContentTranslationUITestBase {
    *
    * @var array
    */
-  public static $modules = [
+  protected static $modules = [
     'language',
     'content_translation',
     'block',
@@ -48,7 +46,7 @@ class BlockContentTranslationUITest extends ContentTranslationUITestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     $this->entityTypeId = 'block_content';
     $this->bundle = 'basic';
     $this->testLanguageSelector = FALSE;
@@ -82,31 +80,6 @@ class BlockContentTranslationUITest extends ContentTranslationUITestBase {
     ]);
   }
 
-  /**
-   * Creates a custom block.
-   *
-   * @param bool|string $title
-   *   (optional) Title of block. When no value is given uses a random name.
-   *   Defaults to FALSE.
-   * @param bool|string $bundle
-   *   (optional) Bundle name. When no value is given, defaults to
-   *   $this->bundle. Defaults to FALSE.
-   *
-   * @return \Drupal\block_content\Entity\BlockContent
-   *   Created custom block.
-   */
-  protected function createBlockContent($title = FALSE, $bundle = FALSE) {
-    $title = $title ?: $this->randomMachineName();
-    $bundle = $bundle ?: $this->bundle;
-    $block_content = BlockContent::create([
-      'info' => $title,
-      'type' => $bundle,
-      'langcode' => 'en',
-    ]);
-    $block_content->save();
-    return $block_content;
-  }
-
   /**
    * {@inheritdoc}
    */
@@ -158,28 +131,6 @@ class BlockContentTranslationUITest extends ContentTranslationUITestBase {
     $this->assertLinkByHref('block/' . $entity->id() . '/translations');
   }
 
-  /**
-   * Test that no metadata is stored for a disabled bundle.
-   */
-  public function testDisabledBundle() {
-    // Create a bundle that does not have translation enabled.
-    $disabled_bundle = $this->randomMachineName();
-    $bundle = BlockContentType::create([
-      'id' => $disabled_bundle,
-      'label' => $disabled_bundle,
-      'revision' => FALSE,
-    ]);
-    $bundle->save();
-
-    // Create a block content for each bundle.
-    $enabled_block_content = $this->createBlockContent();
-    $disabled_block_content = $this->createBlockContent(FALSE, $bundle->id());
-
-    // Make sure that only a single row was inserted into the block table.
-    $rows = Database::getConnection()->query('SELECT * FROM {block_content_field_data} WHERE id = :id', [':id' => $enabled_block_content->id()])->fetchAll();
-    $this->assertEqual(1, count($rows));
-  }
-
   /**
    * {@inheritdoc}
    */
