@@ -16,7 +16,7 @@ class BookBreadcrumbTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['book', 'block', 'book_breadcrumb_test'];
+  protected static $modules = ['book', 'block', 'book_breadcrumb_test'];
 
   /**
    * {@inheritdoc}
@@ -47,7 +47,7 @@ class BookBreadcrumbTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->drupalPlaceBlock('system_breadcrumb_block');
     $this->drupalPlaceBlock('page_title_block');
@@ -156,7 +156,7 @@ class BookBreadcrumbTest extends BrowserTestBase {
       $got_breadcrumb[] = $link->getText();
     }
     // Home link and four parent book nodes should be in the breadcrumb.
-    $this->assertEqual(5, count($got_breadcrumb));
+    $this->assertCount(5, $got_breadcrumb);
     $this->assertEqual($nodes[3]->getTitle(), end($got_breadcrumb));
     $edit = [
       'title[0][value]' => 'Updated node5 title',
@@ -169,7 +169,7 @@ class BookBreadcrumbTest extends BrowserTestBase {
     foreach ($links as $link) {
       $got_breadcrumb[] = $link->getText();
     }
-    $this->assertEqual(5, count($got_breadcrumb));
+    $this->assertCount(5, $got_breadcrumb);
     $this->assertEqual($edit['title[0][value]'], end($got_breadcrumb));
   }
 
@@ -190,7 +190,7 @@ class BookBreadcrumbTest extends BrowserTestBase {
     foreach ($links as $link) {
       $got_breadcrumb[] = $link->getText();
     }
-    $this->assertEqual(5, count($got_breadcrumb));
+    $this->assertCount(5, $got_breadcrumb);
     $this->assertEqual($edit['title[0][value]'], end($got_breadcrumb));
     $config = $this->container->get('config.factory')->getEditable('book_breadcrumb_test.settings');
     $config->set('hide', TRUE)->save();
@@ -200,10 +200,10 @@ class BookBreadcrumbTest extends BrowserTestBase {
     foreach ($links as $link) {
       $got_breadcrumb[] = $link->getText();
     }
-    $this->assertEqual(4, count($got_breadcrumb));
+    $this->assertCount(4, $got_breadcrumb);
     $this->assertEqual($nodes[2]->getTitle(), end($got_breadcrumb));
     $this->drupalGet($nodes[3]->toUrl());
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
   }
 
 }
