@@ -21,7 +21,12 @@ class BookTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['book', 'block', 'node_access_test', 'book_test'];
+  protected static $modules = [
+    'book',
+    'block',
+    'node_access_test',
+    'book_test',
+  ];
 
   /**
    * {@inheritdoc}
@@ -52,7 +57,7 @@ class BookTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->drupalPlaceBlock('system_breadcrumb_block');
     $this->drupalPlaceBlock('page_title_block');
@@ -209,11 +214,11 @@ class BookTest extends BrowserTestBase {
 
     // Make sure we can't export an unsupported format.
     $this->drupalGet('book/export/foobar/' . $this->book->id());
-    $this->assertResponse('404', 'Unsupported export format returned "not found".');
+    $this->assertSession()->statusCodeEquals(404);
 
     // Make sure we get a 404 on a not existing book node.
     $this->drupalGet('book/export/html/123');
-    $this->assertResponse('404', 'Not existing book node returned "not found".');
+    $this->assertSession()->statusCodeEquals(404);
 
     // Make sure an anonymous user cannot view printer-friendly version.
     $this->drupalLogout();
@@ -224,14 +229,14 @@ class BookTest extends BrowserTestBase {
 
     // Try getting the URL directly, and verify it fails.
     $this->drupalGet('book/export/html/' . $this->book->id());
-    $this->assertResponse('403', 'Anonymous user properly forbidden.');
+    $this->assertSession()->statusCodeEquals(403);
 
     // Now grant anonymous users permission to view the printer-friendly
     // version and verify that node access restrictions still prevent them from
     // seeing it.
     user_role_grant_permissions(RoleInterface::ANONYMOUS_ID, ['access printer-friendly version']);
     $this->drupalGet('book/export/html/' . $this->book->id());
-    $this->assertResponse('403', 'Anonymous user properly forbidden from seeing the printer-friendly version when denied by node access.');
+    $this->assertSession()->statusCodeEquals(403);
   }
 
   /**
@@ -351,9 +356,11 @@ class BookTest extends BrowserTestBase {
     $this->drupalLogin($this->adminUser);
     $edit = [];
 
-    // Test access to delete top-level and child book nodes.
+    // Ensure that the top-level book node cannot be deleted.
     $this->drupalGet('node/' . $this->book->id() . '/outline/remove');
-    $this->assertResponse('403', 'Deleting top-level book node properly forbidden.');
+    $this->assertSession()->statusCodeEquals(403);
+
+    // Ensure that a child book node can be deleted.
     $this->drupalPostForm('node/' . $nodes[4]->id() . '/outline/remove', $edit, t('Remove'));
     $node_storage->resetCache([$nodes[4]->id()]);
     $node4 = $node_storage->load($nodes[4]->id());
@@ -379,7 +386,7 @@ class BookTest extends BrowserTestBase {
     // Delete parent, and visit a child page.
     $this->drupalPostForm($this->book->toUrl('delete-form'), [], t('Delete'));
     $this->drupalGet($nodes[0]->toUrl());
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText($nodes[0]->label());
     // The book parents should be updated.
     $node_storage = \Drupal::entityTypeManager()->getStorage('node');
