@@ -16,7 +16,7 @@ class ConfigEntityStatusUITest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['config_test'];
+  protected static $modules = ['config_test'];
 
   /**
    * {@inheritdoc}
@@ -42,14 +42,14 @@ class ConfigEntityStatusUITest extends BrowserTestBase {
     $disable_url = $entity->toUrl('disable');
     $this->assertLinkByHref($disable_url->toString());
     $this->drupalGet($disable_url);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertNoLinkByHref($disable_url->toString());
 
     // Enable an entity.
     $enable_url = $entity->toUrl('enable');
     $this->assertLinkByHref($enable_url->toString());
     $this->drupalGet($enable_url);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertNoLinkByHref($enable_url->toString());
   }
 
