@@ -3,7 +3,10 @@
 namespace Drupal\Tests\config_translation\Functional;
 
 use Drupal\Component\Utility\Html;
+use Drupal\field\Entity\FieldConfig;
+use Drupal\field\Entity\FieldStorageConfig;
 use Drupal\language\Entity\ConfigurableLanguage;
+use Drupal\node\Entity\NodeType;
 use Drupal\Tests\BrowserTestBase;
 
 /**
@@ -18,7 +21,7 @@ class ConfigTranslationOverviewTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = [
+  protected static $modules = [
     'block',
     'config_test',
     'config_translation',
@@ -26,6 +29,8 @@ class ConfigTranslationOverviewTest extends BrowserTestBase {
     'contact',
     'contextual',
     'entity_test_operation',
+    'field_ui',
+    'node',
     'views',
     'views_ui',
   ];
@@ -49,7 +54,7 @@ class ConfigTranslationOverviewTest extends BrowserTestBase {
    */
   protected $localeStorage;
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $permissions = [
       'translate configuration',
@@ -82,7 +87,7 @@ class ConfigTranslationOverviewTest extends BrowserTestBase {
     // Make sure there is only a single operation for each dropbutton, either
     // 'List' or 'Translate'.
     foreach ($this->cssSelect('ul.dropbutton') as $i => $dropbutton) {
-      $this->assertIdentical(1, count($dropbutton->findAll('xpath', 'li')));
+      $this->assertCount(1, $dropbutton->findAll('xpath', 'li'));
       $this->assertTrue(($dropbutton->getText() === 'Translate') || ($dropbutton->getText() === 'List'));
     }
 
@@ -108,7 +113,7 @@ class ConfigTranslationOverviewTest extends BrowserTestBase {
       // Make sure there is only a single 'Translate' operation for each
       // dropbutton.
       foreach ($this->cssSelect('ul.dropbutton') as $i => $dropbutton) {
-        $this->assertIdentical(1, count($dropbutton->findAll('xpath', 'li')));
+        $this->assertCount(1, $dropbutton->findAll('xpath', 'li'));
         $this->assertIdentical('Translate', $dropbutton->getText());
       }
 
@@ -171,4 +176,31 @@ class ConfigTranslationOverviewTest extends BrowserTestBase {
     $this->assertNoText($overridden_label);
   }
 
+  /**
+   * Tests the field listing for the translate operation.
+   */
+  public function testListingFieldsPage() {
+    // Create a content type.
+    $node_type = NodeType::create([
+      'type' => 'basic',
+      'name' => 'Basic',
+    ]);
+    $node_type->save();
+
+    $field = FieldConfig::create([
+      // The field storage is guaranteed to exist because it is supplied by the
+      // node module.
+      'field_storage' => FieldStorageConfig::loadByName('node', 'body'),
+      'bundle' => $node_type->id(),
+      'label' => 'Body',
+      'settings' => ['display_summary' => FALSE],
+    ]);
+    $field->save();
+
+    $this->drupalGet('admin/config/regional/config-translation/node_fields');
+    $this->assertText('Body');
+    $this->assertText('Basic');
+    $this->assertLinkByHref('admin/structure/types/manage/basic/fields/node.basic.body/translate');
+  }
+
 }
