@@ -5,27 +5,33 @@ namespace Drupal\Tests\content_translation\Functional;
 use Drupal\Tests\BrowserTestBase;
 
 /**
- * Tests the content translation behaviours on entity bundle UI.
+ * Tests the content translation behaviors on entity bundle UI.
  *
  * @group content_translation
  */
 class ContentTranslationEntityBundleUITest extends BrowserTestBase {
 
-  public static $modules = ['language', 'content_translation', 'node', 'comment', 'field_ui'];
+  protected static $modules = [
+    'language',
+    'content_translation',
+    'node',
+    'comment',
+    'field_ui',
+  ];
 
   /**
    * {@inheritdoc}
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $user = $this->drupalCreateUser(['access administration pages', 'administer languages', 'administer content translation', 'administer content types']);
     $this->drupalLogin($user);
   }
 
   /**
-   * Tests content types default translation behaviour.
+   * Tests content types default translation behavior.
    */
   public function testContentTypeUI() {
     // Create first content type.
