@@ -18,7 +18,7 @@ class FileListingTest extends FileFieldTestBase {
    *
    * @var array
    */
-  public static $modules = ['views', 'file', 'image', 'entity_test'];
+  protected static $modules = ['views', 'file', 'image', 'entity_test'];
 
   /**
    * {@inheritdoc}
@@ -32,7 +32,7 @@ class FileListingTest extends FileFieldTestBase {
    */
   protected $baseUser;
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     // This test expects unused managed files to be marked as a temporary file.
@@ -50,6 +50,7 @@ class FileListingTest extends FileFieldTestBase {
    *
    * @param $usage array
    *   Array of file usage information as returned from file_usage subsystem.
+   *
    * @return int
    *   Total usage count.
    */
@@ -74,7 +75,7 @@ class FileListingTest extends FileFieldTestBase {
     // Users without sufficient permissions should not see file listing.
     $this->drupalLogin($this->baseUser);
     $this->drupalGet('admin/content/files');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
 
     // Log in with user with right permissions and test listing.
     $this->drupalLogin($this->adminUser);
@@ -84,17 +85,17 @@ class FileListingTest extends FileFieldTestBase {
     }
 
     $this->drupalGet('admin/content/files');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText('No files available.');
     $this->drupalGet('admin/content/files');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Create a file with no usage.
     $file = $this->createFile();
 
     $this->drupalGet('admin/content/files/usage/' . $file->id());
-    $this->assertResponse(200);
-    $this->assertTitle(t('File usage information for @file | Drupal', ['@file' => $file->getFilename()]));
+    $this->assertSession()->statusCodeEquals(200);
+    $this->assertTitle('File usage information for ' . $file->getFilename() . ' | Drupal');
 
     foreach ($nodes as &$node) {
       $this->drupalGet('node/' . $node->id() . '/edit');
@@ -134,14 +135,14 @@ class FileListingTest extends FileFieldTestBase {
     $this->assertRaw('admin/content/files/usage/' . $file->id() . '">' . $usage);
 
     $result = $this->xpath("//td[contains(@class, 'views-field-status') and contains(text(), :value)]", [':value' => 'Temporary']);
-    $this->assertEqual(1, count($result), 'Unused file marked as temporary.');
+    $this->assertCount(1, $result, 'Unused file marked as temporary.');
 
     // Test file usage page.
     foreach ($nodes as $node) {
       $file = File::load($node->file->target_id);
       $usage = $file_usage->listUsage($file);
       $this->drupalGet('admin/content/files/usage/' . $file->id());
-      $this->assertResponse(200);
+      $this->assertSession()->statusCodeEquals(200);
       $this->assertText($node->getTitle(), 'Node title found on usage page.');
       $this->assertText('node', 'Registering entity type found on usage page.');
       $this->assertText('file', 'Registering module found on usage page.');
@@ -197,7 +198,7 @@ class FileListingTest extends FileFieldTestBase {
     // Load the file usage page for the created and attached file.
     $this->drupalGet('admin/content/files/usage/' . $file->id());
 
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     // Entity name should be displayed, but not linked if Entity::toUrl
     // throws an exception
     $this->assertText($entity_name, 'Entity name is added to file usage listing.');
