@@ -20,14 +20,14 @@ class FilePrivateTest extends FileFieldTestBase {
    *
    * @var array
    */
-  public static $modules = ['node_access_test', 'field_test'];
+  protected static $modules = ['node_access_test', 'field_test'];
 
   /**
    * {@inheritdoc}
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     node_access_test_add_field(NodeType::load('article'));
     node_access_rebuild();
@@ -60,10 +60,11 @@ class FilePrivateTest extends FileFieldTestBase {
     $this->assertRaw($node_file->getFilename(), 'File reference is displayed after attaching it');
     // Ensure the file can be downloaded.
     $this->drupalGet(file_create_url($node_file->getFileUri()));
-    $this->assertResponse(200, 'Confirmed that the generated URL is correct by downloading the shipped file.');
+    $this->assertSession()->statusCodeEquals(200);
     $this->drupalLogOut();
+    // Ensure the file cannot be downloaded after logging out.
     $this->drupalGet(file_create_url($node_file->getFileUri()));
-    $this->assertResponse(403, 'Confirmed that access is denied for the file without the needed permission.');
+    $this->assertSession()->statusCodeEquals(403);
 
     // Create a field with no view access. See
     // field_test_entity_field_access().
@@ -79,7 +80,7 @@ class FilePrivateTest extends FileFieldTestBase {
     // Ensure the file cannot be downloaded.
     $file_url = file_create_url($node_file->getFileUri());
     $this->drupalGet($file_url);
-    $this->assertResponse(403, 'Confirmed that access is denied for the file without view field access permission.');
+    $this->assertSession()->statusCodeEquals(403);
 
     // Attempt to reuse the file when editing a node.
     $edit = [];
@@ -114,20 +115,20 @@ class FilePrivateTest extends FileFieldTestBase {
     \Drupal::state()->set('file_test.allow_all', TRUE);
     // Delete the node.
     $node->delete();
-    // Ensure the file can still be downloaded by the owner.
+    // Ensure the temporary file can still be downloaded by the owner.
     $this->drupalGet($file_url);
-    $this->assertResponse(200, 'Confirmed that the owner still has access to the temporary file.');
+    $this->assertSession()->statusCodeEquals(200);
 
-    // Ensure the file cannot be downloaded by an anonymous user.
+    // Ensure the temporary file cannot be downloaded by an anonymous user.
     $this->drupalLogout();
     $this->drupalGet($file_url);
-    $this->assertResponse(403, 'Confirmed that access is denied for an anonymous user to the temporary file.');
+    $this->assertSession()->statusCodeEquals(403);
 
-    // Ensure the file cannot be downloaded by another user.
+    // Ensure the temporary file cannot be downloaded by another user.
     $account = $this->drupalCreateUser();
     $this->drupalLogin($account);
     $this->drupalGet($file_url);
-    $this->assertResponse(403, 'Confirmed that access is denied for another user to the temporary file.');
+    $this->assertSession()->statusCodeEquals(403);
 
     // As an anonymous user, create a temporary file with no references and
     // confirm that only the session that uploaded it may view it.
@@ -146,18 +147,20 @@ class FilePrivateTest extends FileFieldTestBase {
     /** @var \Drupal\file\FileStorageInterface $file_storage */
     $file_storage = $this->container->get('entity_type.manager')->getStorage('file');
     $files = $file_storage->loadByProperties(['uid' => 0]);
-    $this->assertEqual(1, count($files), 'Loaded one anonymous file.');
+    $this->assertCount(1, $files, 'Loaded one anonymous file.');
     $file = end($files);
     $this->assertTrue($file->isTemporary(), 'File is temporary.');
     $usage = $this->container->get('file.usage')->listUsage($file);
     $this->assertEmpty($usage, 'No file usage found.');
     $file_url = file_create_url($file->getFileUri());
+    // Ensure the anonymous uploader has access to the temporary file.
     $this->drupalGet($file_url);
-    $this->assertResponse(200, 'Confirmed that the anonymous uploader has access to the temporary file.');
+    $this->assertSession()->statusCodeEquals(200);
     // Close the prior connection and remove the session cookie.
     $this->getSession()->reset();
+    // Ensure that a different anonymous user cannot access the temporary file.
     $this->drupalGet($file_url);
-    $this->assertResponse(403, 'Confirmed that another anonymous user cannot access the temporary file.');
+    $this->assertSession()->statusCodeEquals(403);
 
     // As an anonymous user, create a permanent file, then remove all
     // references to the file (so that it becomes temporary again) and confirm
@@ -180,12 +183,14 @@ class FilePrivateTest extends FileFieldTestBase {
     $usage = $this->container->get('file.usage')->listUsage($file);
     $this->assertEmpty($usage, 'No file usage found.');
     $file_url = file_create_url($file->getFileUri());
+    // Ensure the anonymous uploader has access to the temporary file.
     $this->drupalGet($file_url);
-    $this->assertResponse(200, 'Confirmed that the anonymous uploader has access to the file whose references were removed.');
+    $this->assertSession()->statusCodeEquals(200);
     // Close the prior connection and remove the session cookie.
     $this->getSession()->reset();
+    // Ensure that a different anonymous user cannot access the temporary file.
     $this->drupalGet($file_url);
-    $this->assertResponse(403, 'Confirmed that another anonymous user cannot access the file whose references were removed.');
+    $this->assertSession()->statusCodeEquals(403);
 
     // As an anonymous user, create a permanent file that is referenced by a
     // published node and confirm that all anonymous users may view it.
@@ -201,12 +206,14 @@ class FilePrivateTest extends FileFieldTestBase {
     $usage = $this->container->get('file.usage')->listUsage($file);
     $this->assertCount(1, $usage, 'File usage found.');
     $file_url = file_create_url($file->getFileUri());
+    // Ensure the anonymous uploader has access to the file.
     $this->drupalGet($file_url);
-    $this->assertResponse(200, 'Confirmed that the anonymous uploader has access to the permanent file that is referenced by a published node.');
+    $this->assertSession()->statusCodeEquals(200);
     // Close the prior connection and remove the session cookie.
     $this->getSession()->reset();
+    // Ensure that a different anonymous user can access the file.
     $this->drupalGet($file_url);
-    $this->assertResponse(200, 'Confirmed that another anonymous user also has access to the permanent file that is referenced by a published node.');
+    $this->assertSession()->statusCodeEquals(200);
 
     // As an anonymous user, create a permanent file that is referenced by an
     // unpublished node and confirm that no anonymous users may view it (even
@@ -226,12 +233,14 @@ class FilePrivateTest extends FileFieldTestBase {
     $usage = $this->container->get('file.usage')->listUsage($file);
     $this->assertCount(1, $usage, 'File usage found.');
     $file_url = file_create_url($file->getFileUri());
+    // Ensure the anonymous uploader cannot access to the file.
     $this->drupalGet($file_url);
-    $this->assertResponse(403, 'Confirmed that the anonymous uploader cannot access the permanent file when it is referenced by an unpublished node.');
+    $this->assertSession()->statusCodeEquals(403);
     // Close the prior connection and remove the session cookie.
     $this->getSession()->reset();
+    // Ensure that a different anonymous user cannot access the temporary file.
     $this->drupalGet($file_url);
-    $this->assertResponse(403, 'Confirmed that another anonymous user cannot access the permanent file when it is referenced by an unpublished node.');
+    $this->assertSession()->statusCodeEquals(403);
   }
 
 }
