@@ -2,6 +2,8 @@
 
 namespace Drupal\Tests\file\Kernel;
 
+use Drupal\Core\File\FileSystemInterface;
+
 /**
  * Tests the file url.
  *
@@ -15,9 +17,9 @@ class FileUrlTest extends FileManagedUnitTestBase {
   public function testFilesUrlWithDifferentHostName() {
     $test_base_url = 'http://www.example.com/cdn';
     $this->setSetting('file_public_base_url', $test_base_url);
-    $filepath = file_create_filename('test.txt', '');
+    $filepath = \Drupal::service('file_system')->createFilename('test.txt', '');
     $directory_uri = 'public://' . dirname($filepath);
-    file_prepare_directory($directory_uri, FILE_CREATE_DIRECTORY);
+    \Drupal::service('file_system')->prepareDirectory($directory_uri, FileSystemInterface::CREATE_DIRECTORY);
     $file = $this->createFile($filepath, NULL, 'public');
     $url = file_create_url($file->getFileUri());
     $expected_url = $test_base_url . '/' . basename($filepath);
