@@ -2,6 +2,7 @@
 
 namespace Drupal\Tests\file\Kernel;
 
+use Drupal\Core\Database\Database;
 use Drupal\field\Entity\FieldConfig;
 use Drupal\field\Entity\FieldStorageConfig;
 use Drupal\language\Entity\ConfigurableLanguage;
@@ -21,7 +22,8 @@ class UsageTest extends FileManagedUnitTestBase {
    */
   public function testGetUsage() {
     $file = $this->createFile();
-    db_insert('file_usage')
+    $connection = Database::getConnection();
+    $connection->insert('file_usage')
       ->fields([
         'fid' => $file->id(),
         'module' => 'testing',
@@ -30,7 +32,7 @@ class UsageTest extends FileManagedUnitTestBase {
         'count' => 1,
       ])
       ->execute();
-    db_insert('file_usage')
+    $connection->insert('file_usage')
       ->fields([
         'fid' => $file->id(),
         'module' => 'testing',
@@ -42,7 +44,7 @@ class UsageTest extends FileManagedUnitTestBase {
 
     $usage = $this->container->get('file.usage')->listUsage($file);
 
-    $this->assertEqual(count($usage['testing']), 2, 'Returned the correct number of items.');
+    $this->assertCount(2, $usage['testing'], 'Returned the correct number of items.');
     $this->assertTrue(isset($usage['testing']['foo'][1]), 'Returned the correct id.');
     $this->assertTrue(isset($usage['testing']['bar'][2]), 'Returned the correct id.');
     $this->assertEqual($usage['testing']['foo'][1], 1, 'Returned the correct count.');
@@ -61,12 +63,12 @@ class UsageTest extends FileManagedUnitTestBase {
     $file_usage->add($file, 'testing', 'bar', 2);
     $file_usage->add($file, 'testing', 'bar', 2);
 
-    $usage = db_select('file_usage', 'f')
+    $usage = Database::getConnection()->select('file_usage', 'f')
       ->fields('f')
       ->condition('f.fid', $file->id())
       ->execute()
       ->fetchAllAssoc('id');
-    $this->assertEqual(count($usage), 2, 'Created two records');
+    $this->assertCount(2, $usage, 'Created two records');
     $this->assertEqual($usage[1]->module, 'testing', 'Correct module');
     $this->assertEqual($usage[2]->module, 'testing', 'Correct module');
     $this->assertEqual($usage[1]->type, 'foo', 'Correct type');
@@ -104,7 +106,8 @@ class UsageTest extends FileManagedUnitTestBase {
     $file = $this->createFile();
     $file->setPermanent();
     $file_usage = $this->container->get('file.usage');
-    db_insert('file_usage')
+    $connection = Database::getConnection();
+    $connection->insert('file_usage')
       ->fields([
         'fid' => $file->id(),
         'module' => 'testing',
@@ -116,7 +119,7 @@ class UsageTest extends FileManagedUnitTestBase {
 
     // Normal decrement.
     $file_usage->delete($file, 'testing', 'bar', 2);
-    $count = db_select('file_usage', 'f')
+    $count = $connection->select('file_usage', 'f')
       ->fields('f', ['count'])
       ->condition('f.fid', $file->id())
       ->execute()
@@ -125,21 +128,21 @@ class UsageTest extends FileManagedUnitTestBase {
 
     // Multiple decrement and removal.
     $file_usage->delete($file, 'testing', 'bar', 2, 2);
-    $count = db_select('file_usage', 'f')
+    $count = $connection->select('file_usage', 'f')
       ->fields('f', ['count'])
       ->condition('f.fid', $file->id())
       ->execute()
       ->fetchField();
-    $this->assertIdentical(FALSE, $count, 'The count was removed entirely when empty.');
+    $this->assertFalse($count, 'The count was removed entirely when empty.');
 
     // Non-existent decrement.
     $file_usage->delete($file, 'testing', 'bar', 2);
-    $count = db_select('file_usage', 'f')
+    $count = $connection->select('file_usage', 'f')
       ->fields('f', ['count'])
       ->condition('f.fid', $file->id())
       ->execute()
       ->fetchField();
-    $this->assertIdentical(FALSE, $count, 'Decrementing non-exist record complete.');
+    $this->assertFalse($count, 'Decrementing non-exist record complete.');
     return $file;
   }
 
@@ -152,34 +155,35 @@ class UsageTest extends FileManagedUnitTestBase {
   public function createTempFiles() {
     // Temporary file that is old.
     $temp_old = file_save_data('');
-    db_update('file_managed')
+    $connection = Database::getConnection();
+    $connection->update('file_managed')
       ->fields([
         'status' => 0,
         'changed' => REQUEST_TIME - $this->config('system.file')->get('temporary_maximum_age') - 1,
       ])
       ->condition('fid', $temp_old->id())
       ->execute();
-    $this->assertTrue(file_exists($temp_old->getFileUri()), 'Old temp file was created correctly.');
+    $this->assertFileExists($temp_old->getFileUri());
 
     // Temporary file that is new.
     $temp_new = file_save_data('');
-    db_update('file_managed')
+    $connection->update('file_managed')
       ->fields(['status' => 0])
       ->condition('fid', $temp_new->id())
       ->execute();
-    $this->assertTrue(file_exists($temp_new->getFileUri()), 'New temp file was created correctly.');
+    $this->assertFileExists($temp_new->getFileUri());
 
     // Permanent file that is old.
     $perm_old = file_save_data('');
-    db_update('file_managed')
+    $connection->update('file_managed')
       ->fields(['changed' => REQUEST_TIME - $this->config('system.file')->get('temporary_maximum_age') - 1])
       ->condition('fid', $temp_old->id())
       ->execute();
-    $this->assertTrue(file_exists($perm_old->getFileUri()), 'Old permanent file was created correctly.');
+    $this->assertFileExists($perm_old->getFileUri());
 
     // Permanent file that is new.
     $perm_new = file_save_data('');
-    $this->assertTrue(file_exists($perm_new->getFileUri()), 'New permanent file was created correctly.');
+    $this->assertFileExists($perm_new->getFileUri());
     return [$temp_old, $temp_new, $perm_old, $perm_new];
   }
 
@@ -191,10 +195,10 @@ class UsageTest extends FileManagedUnitTestBase {
 
     // Run cron and then ensure that only the old, temp file was deleted.
     $this->container->get('cron')->run();
-    $this->assertFalse(file_exists($temp_old->getFileUri()), 'Old temp file was correctly removed.');
-    $this->assertTrue(file_exists($temp_new->getFileUri()), 'New temp file was correctly ignored.');
-    $this->assertTrue(file_exists($perm_old->getFileUri()), 'Old permanent file was correctly ignored.');
-    $this->assertTrue(file_exists($perm_new->getFileUri()), 'New permanent file was correctly ignored.');
+    $this->assertFileNotExists($temp_old->getFileUri());
+    $this->assertFileExists($temp_new->getFileUri());
+    $this->assertFileExists($perm_old->getFileUri());
+    $this->assertFileExists($perm_new->getFileUri());
   }
 
   /**
@@ -210,10 +214,10 @@ class UsageTest extends FileManagedUnitTestBase {
 
     // Run cron and then ensure that no file was deleted.
     $this->container->get('cron')->run();
-    $this->assertTrue(file_exists($temp_old->getFileUri()), 'Old temp file was correctly ignored.');
-    $this->assertTrue(file_exists($temp_new->getFileUri()), 'New temp file was correctly ignored.');
-    $this->assertTrue(file_exists($perm_old->getFileUri()), 'Old permanent file was correctly ignored.');
-    $this->assertTrue(file_exists($perm_new->getFileUri()), 'New permanent file was correctly ignored.');
+    $this->assertFileExists($temp_old->getFileUri());
+    $this->assertFileExists($temp_new->getFileUri());
+    $this->assertFileExists($perm_old->getFileUri());
+    $this->assertFileExists($perm_new->getFileUri());
   }
 
   /**
@@ -229,10 +233,10 @@ class UsageTest extends FileManagedUnitTestBase {
 
     // Run cron and then ensure that more files were deleted.
     $this->container->get('cron')->run();
-    $this->assertTrue(file_exists($temp_old->getFileUri()), 'Old temp file was correctly ignored.');
-    $this->assertTrue(file_exists($temp_new->getFileUri()), 'New temp file was correctly ignored.');
-    $this->assertTrue(file_exists($perm_old->getFileUri()), 'Old permanent file was correctly ignored.');
-    $this->assertTrue(file_exists($perm_new->getFileUri()), 'New permanent file was correctly ignored.');
+    $this->assertFileExists($temp_old->getFileUri());
+    $this->assertFileExists($temp_new->getFileUri());
+    $this->assertFileExists($perm_old->getFileUri());
+    $this->assertFileExists($perm_new->getFileUri());
   }
 
   /**
