@@ -17,14 +17,22 @@ class ForumNodeAccessTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['node', 'comment', 'forum', 'taxonomy', 'tracker', 'node_access_test', 'block'];
+  protected static $modules = [
+    'node',
+    'comment',
+    'forum',
+    'taxonomy',
+    'tracker',
+    'node_access_test',
+    'block',
+  ];
 
   /**
    * {@inheritdoc}
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     node_access_rebuild();
     node_access_test_add_field(NodeType::load('forum'));
