@@ -26,7 +26,15 @@ class ForumTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['taxonomy', 'comment', 'forum', 'node', 'block', 'menu_ui', 'help'];
+  protected static $modules = [
+    'taxonomy',
+    'comment',
+    'forum',
+    'node',
+    'block',
+    'menu_ui',
+    'help',
+  ];
 
   /**
    * {@inheritdoc}
@@ -81,7 +89,7 @@ class ForumTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->drupalPlaceBlock('system_breadcrumb_block');
     $this->drupalPlaceBlock('page_title_block');
@@ -209,7 +217,7 @@ class ForumTest extends BrowserTestBase {
     $this->assertStringStartsWith('6 new posts', $elements[0]->getText(), 'Number of unread topics found.');
     // Verify that the forum name is in the unread topics text.
     $elements = $this->xpath('//tr[@id=:forum]//em[@class="placeholder"]', $forum_arg);
-    $this->assertContains($this->forum['name'], $elements[0]->getText(), 'Forum name found in unread topics text.');
+    $this->assertStringContainsString($this->forum['name'], $elements[0]->getText(), 'Forum name found in unread topics text.');
 
     // Verify total number of posts in forum.
     $elements = $this->xpath('//tr[@id=:forum]//td[@class="forum__posts"]', $forum_arg);
@@ -227,23 +235,23 @@ class ForumTest extends BrowserTestBase {
     $edit = [];
     $edit['comment_body[0][value]'] = $this->randomMachineName();
     $this->drupalPostForm('node/' . $node->id(), $edit, t('Save'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Test editing a forum topic that has a comment.
     $this->drupalLogin($this->editAnyTopicsUser);
     $this->drupalGet('forum/' . $this->forum['tid']);
     $this->drupalPostForm('node/' . $node->id() . '/edit', [], t('Save'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Test the root forum page title change.
     $this->drupalGet('forum');
     $this->assertCacheTag('config:taxonomy.vocabulary.' . $this->forum['vid']);
-    $this->assertTitle(t('Forums | Drupal'));
+    $this->assertTitle('Forums | Drupal');
     $vocabulary = Vocabulary::load($this->forum['vid']);
     $vocabulary->set('name', 'Discussions');
     $vocabulary->save();
     $this->drupalGet('forum');
-    $this->assertTitle(t('Discussions | Drupal'));
+    $this->assertTitle('Discussions | Drupal');
 
     // Test anonymous action link.
     $this->drupalLogout();
@@ -299,7 +307,7 @@ class ForumTest extends BrowserTestBase {
     // Add forum to the Tools menu.
     $edit = [];
     $this->drupalPostForm('admin/structure/menu/manage/tools', $edit, t('Save'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Edit forum taxonomy.
     // Restoration of the settings fails and causes subsequent tests to fail.
@@ -382,7 +390,7 @@ class ForumTest extends BrowserTestBase {
 
     // Edit the vocabulary.
     $this->drupalPostForm('admin/structure/taxonomy/manage/' . $original_vocabulary->id(), $edit, t('Save'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t('Updated vocabulary %name.', ['%name' => $edit['name']]), 'Vocabulary was edited');
 
     // Grab the newly edited vocabulary.
@@ -426,7 +434,7 @@ class ForumTest extends BrowserTestBase {
 
     // Create forum.
     $this->drupalPostForm('admin/structure/forum/add/' . $type, $edit, t('Save'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $type = ($type == 'container') ? 'forum container' : 'forum';
     $this->assertText(
       t(
@@ -483,7 +491,7 @@ class ForumTest extends BrowserTestBase {
 
     // Assert that the forum no longer exists.
     $this->drupalGet('forum/' . $tid);
-    $this->assertResponse(404, 'The forum was not found');
+    $this->assertSession()->statusCodeEquals(404);
   }
 
   /**
@@ -525,18 +533,18 @@ class ForumTest extends BrowserTestBase {
     $edit['subject[0][value]'] = $this->randomMachineName();
     $edit['comment_body[0][value]'] = $this->randomMachineName();
     $this->drupalPostForm('node/' . $node->id(), $edit, t('Save'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Test replying to a comment.
     $this->clickLink('Reply');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertFieldByName('comment_body[0][value]');
 
     // Log in as the first user.
     $this->drupalLogin($this->adminUser);
     // Check that forum renders properly.
     $this->drupalGet("forum/{$this->forum['tid']}");
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Verify there is no unintentional HTML tag escaping.
     $this->assertNoEscaped('<', '');
@@ -610,9 +618,9 @@ class ForumTest extends BrowserTestBase {
 
     // View forum help node.
     $this->drupalGet('admin/help/forum');
-    $this->assertResponse($response2);
+    $this->assertSession()->statusCodeEquals($response2);
     if ($response2 == 200) {
-      $this->assertTitle(t('Forum | Drupal'), 'Forum help title was displayed');
+      $this->assertTitle('Forum | Drupal');
       $this->assertText(t('Forum'), 'Forum help node was displayed');
     }
 
@@ -625,8 +633,8 @@ class ForumTest extends BrowserTestBase {
 
     // View forum node.
     $this->drupalGet('node/' . $node->id());
-    $this->assertResponse(200);
-    $this->assertTitle($node->label() . ' | Drupal', 'Forum node was displayed');
+    $this->assertSession()->statusCodeEquals(200);
+    $this->assertTitle($node->label() . ' | Drupal');
     $breadcrumb_build = [
       Link::createFromRoute(t('Home'), '<front>'),
       Link::createFromRoute(t('Forums'), 'forum.index'),
@@ -641,9 +649,9 @@ class ForumTest extends BrowserTestBase {
 
     // View forum edit node.
     $this->drupalGet('node/' . $node->id() . '/edit');
-    $this->assertResponse($response);
+    $this->assertSession()->statusCodeEquals($response);
     if ($response == 200) {
-      $this->assertTitle('Edit Forum topic ' . $node->label() . ' | Drupal', 'Forum edit node was displayed');
+      $this->assertTitle('Edit Forum topic ' . $node->label() . ' | Drupal');
     }
 
     if ($response == 200) {
@@ -670,7 +678,7 @@ class ForumTest extends BrowserTestBase {
 
       // Delete forum node.
       $this->drupalPostForm('node/' . $node->id() . '/delete', [], t('Delete'));
-      $this->assertResponse($response);
+      $this->assertSession()->statusCodeEquals($response);
       $this->assertRaw(t('Forum topic %title has been deleted.', ['%title' => $edit['title[0][value]']]), 'Forum node was deleted');
     }
   }
@@ -686,7 +694,7 @@ class ForumTest extends BrowserTestBase {
   private function verifyForumView($forum, $parent = NULL) {
     // View forum page.
     $this->drupalGet('forum/' . $forum['tid']);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertTitle($forum['name'] . ' | Drupal');
 
     $breadcrumb_build = [
