@@ -50,14 +50,16 @@ trait ImageFieldCreationTrait {
     ]);
     $field_config->save();
 
-    entity_get_form_display('node', $type_name, 'default')
+    /** @var \Drupal\Core\Entity\EntityDisplayRepositoryInterface $display_repository */
+    $display_repository = \Drupal::service('entity_display.repository');
+    $display_repository->getFormDisplay('node', $type_name)
       ->setComponent($name, [
         'type' => 'image_image',
         'settings' => $widget_settings,
       ])
       ->save();
 
-    entity_get_display('node', $type_name, 'default')
+    $display_repository->getViewDisplay('node', $type_name)
       ->setComponent($name, [
         'type' => 'image',
         'settings' => $formatter_settings,
