@@ -19,7 +19,7 @@ class LanguageCustomLanguageConfigurationTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['language'];
+  protected static $modules = ['language'];
 
   /**
    * {@inheritdoc}
