@@ -23,7 +23,7 @@ class LanguageTourTest extends TourTestBase {
    *
    * @var array
    */
-  public static $modules = ['block', 'language', 'tour'];
+  protected static $modules = ['block', 'language', 'tour'];
 
   /**
    * {@inheritdoc}
@@ -33,7 +33,7 @@ class LanguageTourTest extends TourTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->adminUser = $this->drupalCreateUser(['administer languages', 'access tour']);
     $this->drupalLogin($this->adminUser);
