@@ -53,7 +53,8 @@ class LanguageTypesTest extends MigrateProcessTestCase {
    */
   public function testStringInput() {
     $this->plugin = new LanguageTypes([], 'map', []);
-    $this->setExpectedException(MigrateException::class, 'The input should be an array');
+    $this->expectException(MigrateException::class);
+    $this->expectExceptionMessage('The input should be an array');
     $this->plugin->transform('foo', $this->migrateExecutable, $this->row, 'destinationproperty');
   }
 
