@@ -24,7 +24,7 @@ class LocaleConfigTranslationTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['locale', 'contact', 'contact_test'];
+  protected static $modules = ['locale', 'contact', 'contact_test'];
 
   /**
    * {@inheritdoc}
@@ -34,7 +34,7 @@ class LocaleConfigTranslationTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     // Add a default locale storage for all these tests.
     $this->storage = $this->container->get('locale.storage');
@@ -90,7 +90,7 @@ class LocaleConfigTranslationTest extends BrowserTestBase {
 
     // Get translation and check we've only got the message.
     $translation = \Drupal::languageManager()->getLanguageConfigOverride($this->langcode, 'system.maintenance')->get();
-    $this->assertEqual(count($translation), 1, 'Got the right number of properties after translation.');
+    $this->assertCount(1, $translation, 'Got the right number of properties after translation.');
     $this->assertEqual($translation['message'], $message);
 
     // Check default medium date format exists and create a translation for it.
@@ -135,7 +135,7 @@ class LocaleConfigTranslationTest extends BrowserTestBase {
 
     // Check the string is unique and has no translation yet.
     $translations = $this->storage->getTranslations(['language' => $this->langcode, 'type' => 'configuration', 'name' => 'image.style.medium']);
-    $this->assertEqual(count($translations), 1);
+    $this->assertCount(1, $translations);
     $translation = reset($translations);
     $this->assertEqual($translation->source, $string->source);
     $this->assertEmpty($translation->translation);
@@ -158,7 +158,9 @@ class LocaleConfigTranslationTest extends BrowserTestBase {
     // Check the right single translation has been created.
     $translations = $this->storage->getTranslations(['language' => $this->langcode, 'type' => 'configuration', 'name' => 'image.style.medium']);
     $translation = reset($translations);
-    $this->assertTrue(count($translations) == 1 && $translation->source == $string->source && $translation->translation == $image_style_label, 'Got only one translation for image configuration.');
+    $this->assertCount(1, $translations, 'Got only one translation for image configuration.');
+    $this->assertEquals($string->source, $translation->source);
+    $this->assertEquals($image_style_label, $translation->translation);
 
     // Try more complex configuration data.
     $translation = \Drupal::languageManager()->getLanguageConfigOverride($this->langcode, 'image.style.medium')->get();
