@@ -18,7 +18,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['language', 'locale', 'system', 'locale_test'];
+  protected static $modules = ['language', 'locale', 'system', 'locale_test'];
 
   /**
    * The configurable language manager used in this test.
@@ -51,7 +51,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->setUpDefaultLanguage();
@@ -386,14 +386,12 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
    *   The configuration name.
    * @param string $langcode
    *   The language code.
-   *
-   * @return bool
-   *   TRUE if the assertion succeeded, FALSE otherwise.
    */
   protected function assertNoConfigOverride($config_name, $langcode) {
     $config_langcode = $this->configFactory->getEditable($config_name)->get('langcode');
     $override = $this->languageManager->getLanguageConfigOverride($langcode, $config_name);
-    return $this->assertNotEqual($config_langcode, $langcode) && $this->assertEqual($override->isNew(), TRUE);
+    $this->assertNotEqual($config_langcode, $langcode);
+    $this->assertEqual($override->isNew(), TRUE);
   }
 
   /**
@@ -407,14 +405,12 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
    *   The configuration value.
    * @param string $langcode
    *   The language code.
-   *
-   * @return bool
-   *   TRUE if the assertion succeeded, FALSE otherwise.
    */
   protected function assertConfigOverride($config_name, $key, $value, $langcode) {
     $config_langcode = $this->configFactory->getEditable($config_name)->get('langcode');
     $override = $this->languageManager->getLanguageConfigOverride($langcode, $config_name);
-    return $this->assertNotEqual($config_langcode, $langcode) && $this->assertEqual($override->get($key), $value);
+    $this->assertNotEqual($config_langcode, $langcode);
+    $this->assertEqual($override->get($key), $value);
   }
 
   /**
@@ -428,14 +424,11 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
    *   The configuration value.
    * @param string $langcode
    *   The language code.
-   *
-   * @return bool
-   *   TRUE if the assertion succeeded, FALSE otherwise.
    */
   protected function assertActiveConfig($config_name, $key, $value, $langcode) {
     $config = $this->configFactory->getEditable($config_name);
-    return $this->assertEqual($config->get('langcode'), $langcode) &&
-      $this->assertIdentical($config->get($key), $value);
+    $this->assertEqual($config->get('langcode'), $langcode);
+    $this->assertIdentical($config->get($key), $value);
   }
 
   /**
@@ -445,9 +438,6 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
    *   The configuration name.
    * @param string $langcode
    *   The language code.
-   *
-   * @return bool
-   *   TRUE if the assertion succeeded, FALSE otherwise.
    */
   protected function assertNoTranslation($config_name, $langcode) {
     $strings = $this->stringStorage->getTranslations([
@@ -456,7 +446,7 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
       'language' => $langcode,
       'translated' => TRUE,
     ]);
-    return $this->assertIdentical([], $strings);
+    $this->assertIdentical([], $strings);
   }
 
   /**
@@ -471,9 +461,6 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
    * @param bool $customized
    *   Whether or not the string should be asserted to be customized or not
    *   customized.
-   *
-   * @return bool
-   *   TRUE if the assertion succeeded, FALSE otherwise.
    */
   protected function assertTranslation($config_name, $translation, $langcode, $customized = TRUE) {
     // Make sure a string exists.
@@ -483,20 +470,17 @@ class LocaleConfigSubscriberTest extends KernelTestBase {
       'language' => $langcode,
       'translated' => TRUE,
     ]);
-    $pass = $this->assertIdentical(1, count($strings));
+    $this->assertCount(1, $strings);
     $string = reset($strings);
-    if ($this->assertTrue($string instanceof StringInterface)) {
-      /** @var \Drupal\locale\StringInterface $string */
-      $pass = $pass && $this->assertIdentical($translation, $string->getString());
-      $pass = $pass && $this->assertTrue($string->isTranslation());
-      if ($this->assertTrue($string instanceof TranslationString)) {
-        /** @var \Drupal\locale\TranslationString $string */
-        // Make sure the string is marked as customized so that it does not get
-        // overridden when the string translations are updated.
-        return $pass && $this->assertEqual($customized, $string->customized);
-      }
-    }
-    return FALSE;
+    $this->assertInstanceOf(StringInterface::class, $string);
+    /** @var \Drupal\locale\StringInterface $string */
+    $this->assertIdentical($translation, $string->getString());
+    $this->assertTrue($string->isTranslation());
+    $this->assertInstanceOf(TranslationString::class, $string);
+    /** @var \Drupal\locale\TranslationString $string */
+    // Make sure the string is marked as customized so that it does not get
+    // overridden when the string translations are updated.
+    $this->assertEquals($customized, (bool) $string->customized);
   }
 
 }
