@@ -14,6 +14,11 @@ use Drupal\file\Entity\File;
  */
 class MediaSourceAudioVideoTest extends MediaSourceTestBase {
 
+  /**
+   * {@inheritdoc}
+   */
+  protected $defaultTheme = 'classy';
+
   /**
    * Check the Audio source functionality.
    */
