@@ -34,14 +34,4 @@ class MediaTest extends MediaKernelTestBase {
     $this->assertSame($field_definitions['name']->getDisplayOptions('view'), ['region' => 'hidden']);
   }
 
-  /**
-   * Tests the legacy method used as the default entity owner.
-   *
-   * @group legacy
-   * @expectedDeprecation The ::getCurrentUserId method is deprecated in 8.6.x and will be removed before 9.0.0.
-   */
-  public function testGetCurrentUserId() {
-    $this->assertEquals(['1'], Media::getCurrentUserId());
-  }
-
 }
