@@ -10,7 +10,6 @@ use Drupal\menu_link_content\MenuLinkContentInterface;
 use Drupal\migrate\MigrateLookupInterface;
 use Drupal\migrate\MigrateSkipRowException;
 use Drupal\migrate\Plugin\migrate\process\MenuLinkParent;
-use Drupal\migrate\Plugin\MigrateProcessInterface;
 use Drupal\migrate\Plugin\MigrationInterface;
 
 /**
@@ -52,7 +51,7 @@ class MenuLinkParentTest extends MigrateProcessTestCase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->migration = $this->prophesize(MigrationInterface::class);
     $this->migrateLookup = $this->prophesize(MigrateLookupInterface::class);
@@ -96,32 +95,4 @@ class MenuLinkParentTest extends MigrateProcessTestCase {
     $this->assertEquals('menu_link_content:fe151460-dfa2-4133-8864-c1746f28ab27', $result);
   }
 
-  /**
-   * Tests the plugin when the parent is an external link.
-   *
-   * @covers ::transform
-   *
-   * @group legacy
-   *
-   * @expectedDeprecation Passing a migration process plugin as the fourth argument to Drupal\migrate\Plugin\migrate\process\MenuLinkParent::__construct is deprecated in drupal:8.8.0 and will throw an error in drupal:9.0.0. Pass the migrate.lookup service instead. See https://www.drupal.org/node/3047268
-   */
-  public function testLegacyTransformExternal() {
-    $migration_plugin = $this->prophesize(MigrateProcessInterface::class);
-    $menu_link_manager = $this->prophesize(MenuLinkManagerInterface::class);
-    $menu_link_storage = $this->prophesize(EntityStorageInterface::class);
-    $menu_link_content = $this->prophesize(MenuLinkContentInterface::class);
-    $menu_link_content->getPluginId()->willReturn('menu_link_content:fe151460-dfa2-4133-8864-c1746f28ab27');
-    $menu_link_storage->loadByProperties([
-      'link__uri' => 'http://example.com',
-    ])->willReturn([
-      9054 => $menu_link_content,
-    ]);
-    $plugin = $this->prophesize(PluginInspectionInterface::class);
-    $menu_link_manager->createInstance('menu_link_content:fe151460-dfa2-4133-8864-c1746f28ab27')->willReturn($plugin->reveal());
-    $plugin = new MenuLinkParent([], 'map', [], $migration_plugin->reveal(), $menu_link_manager->reveal(), $menu_link_storage->reveal());
-
-    $result = $plugin->transform([1, 'admin', 'http://example.com'], $this->migrateExecutable, $this->row, 'destinationproperty');
-    $this->assertEquals('menu_link_content:fe151460-dfa2-4133-8864-c1746f28ab27', $result);
-  }
-
 }
