@@ -3,11 +3,8 @@
 namespace Drupal\Tests\migrate_drupal\Kernel\d7;
 
 use Drupal\comment\Entity\CommentType;
-use Drupal\Component\Plugin\Exception\PluginNotFoundException;
 use Drupal\field\Plugin\migrate\source\d7\FieldInstance;
-use Drupal\migrate_drupal\FieldDiscovery;
 use Drupal\migrate_drupal\FieldDiscoveryInterface;
-use Drupal\migrate_drupal\Plugin\MigrateFieldPluginManagerInterface;
 use Drupal\node\Entity\NodeType;
 use Drupal\taxonomy\Entity\Vocabulary;
 use Drupal\Tests\migrate_drupal\Traits\FieldDiscoveryTestTrait;
@@ -26,7 +23,7 @@ class FieldDiscoveryTest extends MigrateDrupal7TestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = [
+  protected static $modules = [
     'comment',
     'datetime',
     'file',
@@ -70,7 +67,7 @@ class FieldDiscoveryTest extends MigrateDrupal7TestBase {
   /**
    * {@inheritdoc}
    */
-  public function setUp() {
+  public function setUp(): void {
     parent::setUp();
     $this->installConfig(static::$modules);
     $node_types = [
@@ -78,6 +75,7 @@ class FieldDiscoveryTest extends MigrateDrupal7TestBase {
       'article' => 'comment_node_article',
       'blog' => 'comment_node_blog',
       'book' => 'comment_node_book',
+      'et' => 'comment_node_et',
       'forum' => 'comment_forum',
       'test_content_type' => 'comment_node_test_content_type',
     ];
@@ -95,7 +93,11 @@ class FieldDiscoveryTest extends MigrateDrupal7TestBase {
     }
 
     Vocabulary::create(['vid' => 'test_vocabulary'])->save();
-    $this->executeMigrations(['d7_field', 'd7_field_instance']);
+    $this->executeMigrations([
+      'd7_field',
+      'd7_taxonomy_vocabulary',
+      'd7_field_instance',
+    ]);
 
     $this->fieldDiscovery = $this->container->get('migrate_drupal.field_discovery');
     $this->migrationPluginManager = $this->container->get('plugin.manager.migration');
@@ -148,6 +150,9 @@ class FieldDiscoveryTest extends MigrateDrupal7TestBase {
       'field_datetime_without_time',
       'field_date_without_time',
       'field_float_list',
+      'field_training',
+      'field_sector',
+      'field_chancellor',
     ];
     $this->assertFieldProcessKeys($this->fieldDiscovery, $this->migrationPluginManager, '7', $expected_process_keys);
   }
@@ -274,9 +279,9 @@ class FieldDiscoveryTest extends MigrateDrupal7TestBase {
     $this->assertArrayHasKey('test_vocabulary', $actual_fields['taxonomy_term']);
     $this->assertArrayHasKey('user', $actual_fields['user']);
     $this->assertArrayHasKey('test_content_type', $actual_fields['node']);
-    $this->assertSame(6, count($actual_fields['node']));
-    $this->assertSame(6, count($actual_fields['comment']));
-    $this->assertSame(22, count($actual_fields['node']['test_content_type']));
+    $this->assertCount(7, $actual_fields['node']);
+    $this->assertCount(6, $actual_fields['comment']);
+    $this->assertCount(22, $actual_fields['node']['test_content_type']);
     foreach ($actual_fields as $entity_type_id => $bundles) {
       foreach ($bundles as $bundle => $fields) {
         foreach ($fields as $field_name => $field_info) {
@@ -308,59 +313,4 @@ class FieldDiscoveryTest extends MigrateDrupal7TestBase {
     ]);
   }
 
-  /**
-   * Tests the fallback to deprecated CCK Plugin Manager.
-   *
-   * @covers ::getCckPluginManager
-   * @group legacy
-   * @expectedDeprecation TextField is deprecated in Drupal 8.3.x and will be removed before Drupal 9.0.x. Use \Drupal\text\Plugin\migrate\field\d6\TextField or \Drupal\text\Plugin\migrate\field\d7\TextField instead.
-   * @expectedDeprecation CckFieldPluginBase is deprecated in Drupal 8.3.x and will be be removed before Drupal 9.0.x. Use \Drupal\migrate_drupal\Plugin\migrate\field\FieldPluginBase instead.
-   * @expectedDeprecation MigrateCckFieldInterface is deprecated in Drupal 8.3.x and will be removed before Drupal 9.0.x. Use \Drupal\migrate_drupal\Annotation\MigrateField instead.
-   */
-  public function testGetCckPluginManager() {
-    $definition = [
-      'migration_tags' => ['Drupal 7'],
-    ];
-    $migration = $this->migrationPluginManager->createStubMigration($definition);
-    $field_plugin_manager = $this->prophesize(MigrateFieldPluginManagerInterface::class);
-    $field_plugin_manager->getPluginIdFromFieldType('text_long', ['core' => '7'], $migration)->willThrow(PluginNotFoundException::class);
-    $field_discovery = new FieldDiscovery($field_plugin_manager->reveal(), $this->migrationPluginManager, $this->logger);
-    $field_discovery->addBundleFieldProcesses($migration, 'comment', 'comment_node_page');
-    $actual_process = $migration->getProcess();
-    $expected_process = [
-      'comment_body' => [
-        0 => [
-          'plugin' => 'sub_process',
-          'source' => 'comment_body',
-          'process' => [
-            'value' => 'value',
-            'format' => [
-              0 => [
-                'plugin' => 'static_map',
-                'bypass' => TRUE,
-                'source' => 'format',
-                'map' => [
-                  0 => NULL,
-                ],
-              ],
-              1 => [
-                'plugin' => 'skip_on_empty',
-                'method' => 'process',
-              ],
-              2 => [
-                'plugin' => 'migration',
-                'migration' => [
-                  0 => 'd6_filter_format',
-                  1 => 'd7_filter_format',
-                ],
-                'source' => 'format',
-              ],
-            ],
-          ],
-        ],
-      ],
-    ];
-    $this->assertEquals($expected_process, $actual_process);
-  }
-
 }
