@@ -21,14 +21,18 @@ class NodeCreationTest extends NodeTestBase {
    *
    * @var array
    */
-  public static $modules = ['node_test_exception', 'dblog', 'test_page_test'];
+  protected static $modules = [
+    'node_test_exception',
+    'dblog',
+    'test_page_test',
+  ];
 
   /**
    * {@inheritdoc}
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $web_user = $this->drupalCreateUser(['create page content', 'edit own page content']);
@@ -44,7 +48,7 @@ class NodeCreationTest extends NodeTestBase {
     // Test /node/add page with only one content type.
     $node_type_storage->load('article')->delete();
     $this->drupalGet('node/add');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertUrl('node/add/page');
     // Create a node.
     $edit = [];
@@ -233,7 +237,7 @@ class NodeCreationTest extends NodeTestBase {
     $this->drupalGet('node/add/page');
 
     $result = $this->xpath('//input[@id="edit-uid-0-value" and contains(@data-autocomplete-path, "user/autocomplete")]');
-    $this->assertEqual(count($result), 0, 'No autocompletion without access user profiles.');
+    $this->assertCount(0, $result, 'No autocompletion without access user profiles.');
 
     $admin_user = $this->drupalCreateUser(['administer nodes', 'create page content', 'access user profiles']);
     $this->drupalLogin($admin_user);
@@ -241,7 +245,7 @@ class NodeCreationTest extends NodeTestBase {
     $this->drupalGet('node/add/page');
 
     $result = $this->xpath('//input[@id="edit-uid-0-target-id" and contains(@data-autocomplete-path, "/entity_reference_autocomplete/user/default")]');
-    $this->assertEqual(count($result), 1, 'Ensure that the user does have access to the autocompletion');
+    $this->assertCount(1, $result, 'Ensure that the user does have access to the autocompletion');
   }
 
   /**
@@ -249,7 +253,7 @@ class NodeCreationTest extends NodeTestBase {
    */
   public function testNodeAddWithoutContentTypes() {
     $this->drupalGet('node/add');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertNoLinkByHref('/admin/structure/types/add');
 
     // Test /node/add page without content types.
@@ -258,7 +262,7 @@ class NodeCreationTest extends NodeTestBase {
     }
 
     $this->drupalGet('node/add');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
 
     $admin_content_types = $this->drupalCreateUser(['administer content types']);
     $this->drupalLogin($admin_content_types);
