@@ -15,7 +15,7 @@ class NodePostSettingsTest extends NodeTestBase {
    */
   protected $defaultTheme = 'classy';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $web_user = $this->drupalCreateUser(['create page content', 'administer content types', 'access user profiles']);
@@ -41,7 +41,7 @@ class NodePostSettingsTest extends NodeTestBase {
     // Check that the post information is displayed.
     $node = $this->drupalGetNodeByTitle($edit['title[0][value]']);
     $elements = $this->xpath('//div[contains(@class, :class)]', [':class' => 'node__submitted']);
-    $this->assertEqual(count($elements), 1, 'Post information is displayed.');
+    $this->assertCount(1, $elements, 'Post information is displayed.');
     $node->delete();
 
     // Set "Basic page" content type to display post information.
@@ -57,7 +57,7 @@ class NodePostSettingsTest extends NodeTestBase {
 
     // Check that the post information is displayed.
     $elements = $this->xpath('//div[contains(@class, :class)]', [':class' => 'node__submitted']);
-    $this->assertEqual(count($elements), 0, 'Post information is not displayed.');
+    $this->assertCount(0, $elements, 'Post information is not displayed.');
   }
 
 }
