@@ -23,7 +23,7 @@ class NodeTypeTest extends NodeTestBase {
    *
    * @var array
    */
-  public static $modules = ['field_ui', 'block'];
+  protected static $modules = ['field_ui', 'block'];
 
   /**
    * {@inheritdoc}
@@ -64,7 +64,7 @@ class NodeTypeTest extends NodeTestBase {
     $this->drupalLogin($web_user);
 
     $this->drupalGet('node/add/' . $type->id());
-    $this->assertResponse(200, 'The new content type can be accessed at node/add.');
+    $this->assertSession()->statusCodeEquals(200);
 
     // Create a content type via the user interface.
     $web_user = $this->drupalCreateUser(['bypass node access', 'administer content types']);
@@ -74,7 +74,7 @@ class NodeTypeTest extends NodeTestBase {
     $this->assertCacheTag('config:node_type_list');
     $this->assertCacheContext('user.permissions');
     $elements = $this->cssSelect('dl.node-type-list dt');
-    $this->assertEqual(3, count($elements));
+    $this->assertCount(3, $elements);
 
     $edit = [
       'name' => 'foo',
@@ -87,7 +87,7 @@ class NodeTypeTest extends NodeTestBase {
 
     $this->drupalGet('node/add');
     $elements = $this->cssSelect('dl.node-type-list dt');
-    $this->assertEqual(4, count($elements));
+    $this->assertCount(4, $elements);
   }
 
   /**
@@ -204,14 +204,14 @@ class NodeTypeTest extends NodeTestBase {
     $this->drupalGet('admin/structure/types/manage/default');
     $this->assertNoLink(t('Delete'));
     $this->drupalGet('admin/structure/types/manage/default/delete');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
     $this->container->get('module_installer')->uninstall(['node_test_config']);
     $this->container = \Drupal::getContainer();
     unset($locked['default']);
     \Drupal::state()->set('node.type.locked', $locked);
     $this->drupalGet('admin/structure/types/manage/default');
     $this->clickLink(t('Delete'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->drupalPostForm(NULL, [], t('Delete'));
     $this->assertFalse((bool) NodeType::load('default'), 'Node type with machine default deleted.');
   }
@@ -245,7 +245,7 @@ class NodeTypeTest extends NodeTestBase {
   public function testNodeTypeNoContentType() {
     /** @var \Drupal\Core\Entity\EntityTypeBundleInfoInterface $bundle_info */
     $bundle_info = \Drupal::service('entity_type.bundle.info');
-    $this->assertEqual(2, count($bundle_info->getBundleInfo('node')), 'The bundle information service has 2 bundles for the Node entity type.');
+    $this->assertCount(2, $bundle_info->getBundleInfo('node'), 'The bundle information service has 2 bundles for the Node entity type.');
     $web_user = $this->drupalCreateUser(['administer content types']);
     $this->drupalLogin($web_user);
 
@@ -261,7 +261,7 @@ class NodeTypeTest extends NodeTestBase {
       ]), 'Empty text when there are no content types in the system is correct.');
 
     $bundle_info->clearCachedBundles();
-    $this->assertEqual(0, count($bundle_info->getBundleInfo('node')), 'The bundle information service has 0 bundles for the Node entity type.');
+    $this->assertCount(0, $bundle_info->getBundleInfo('node'), 'The bundle information service has 0 bundles for the Node entity type.');
   }
 
 }
