@@ -13,9 +13,9 @@ use Drupal\node\Entity\NodeType;
  */
 class NodeConditionTest extends EntityKernelTestBase {
 
-  public static $modules = ['node'];
+  protected static $modules = ['node'];
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     // Create the node bundles required for testing.
