@@ -19,7 +19,14 @@ class OptionsWidgetsTest extends FieldTestBase {
    *
    * @var array
    */
-  public static $modules = ['node', 'options', 'entity_test', 'options_test', 'taxonomy', 'field_ui'];
+  protected static $modules = [
+    'node',
+    'options',
+    'entity_test',
+    'options_test',
+    'taxonomy',
+    'field_ui',
+  ];
 
   /**
    * {@inheritdoc}
@@ -47,7 +54,7 @@ class OptionsWidgetsTest extends FieldTestBase {
    */
   protected $float;
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     // Field storage with cardinality 1.
