@@ -19,14 +19,14 @@ class PathAliasTest extends PathTestBase {
    *
    * @var array
    */
-  public static $modules = ['path'];
+  protected static $modules = ['path'];
 
   /**
    * {@inheritdoc}
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     // Create test user and log in.
@@ -83,15 +83,15 @@ class PathAliasTest extends PathTestBase {
     // Confirm that the alias works.
     $this->drupalGet($edit['alias[0][value]']);
     $this->assertText($node1->label(), 'Alias works.');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     // Confirm that the alias works in a case-insensitive way.
     $this->assertTrue(ctype_lower(ltrim($edit['alias[0][value]'], '/')));
     $this->drupalGet($edit['alias[0][value]']);
     $this->assertText($node1->label(), 'Alias works lower case.');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->drupalGet(mb_strtoupper($edit['alias[0][value]']));
     $this->assertText($node1->label(), 'Alias works upper case.');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Change alias to one containing "exotic" characters.
     $pid = $this->getPID($edit['alias[0][value]']);
@@ -118,13 +118,13 @@ class PathAliasTest extends PathTestBase {
     // Confirm that the alias works.
     $this->drupalGet(mb_strtoupper($edit['alias[0][value]']));
     $this->assertText($node1->label(), 'Changed alias works.');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     $this->container->get('path_alias.manager')->cacheClear();
     // Confirm that previous alias no longer works.
     $this->drupalGet($previous);
     $this->assertNoText($node1->label(), 'Previous alias no longer works.');
-    $this->assertResponse(404);
+    $this->assertSession()->statusCodeEquals(404);
 
     // Create second test node.
     $node2 = $this->drupalCreateNode();
@@ -154,7 +154,7 @@ class PathAliasTest extends PathTestBase {
     // Confirm that the alias no longer works.
     $this->drupalGet($edit['alias[0][value]']);
     $this->assertNoText($node1->label(), 'Alias was successfully deleted.');
-    $this->assertResponse(404);
+    $this->assertSession()->statusCodeEquals(404);
 
     // Create a really long alias.
     $edit = [];
@@ -203,7 +203,7 @@ class PathAliasTest extends PathTestBase {
     $this->drupalGet($edit['alias[0][value]']);
     $this->assertNoText($node4->label(), 'Previous alias no longer works.');
     $this->assertText($node2->label(), 'Alias works.');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Update an existing alias to use a duplicate alias.
     $pid = $this->getPID($node3_alias);
@@ -242,7 +242,7 @@ class PathAliasTest extends PathTestBase {
     // Confirm that the alias works.
     $this->drupalGet($edit['path[0][alias]']);
     $this->assertText($node1->label(), 'Alias works.');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Confirm the 'canonical' and 'shortlink' URLs.
     $elements = $this->xpath("//link[contains(@rel, 'canonical') and contains(@href, '" . $edit['path[0][alias]'] . "')]");
@@ -273,12 +273,12 @@ class PathAliasTest extends PathTestBase {
     // Confirm that the alias works.
     $this->drupalGet(mb_strtoupper($edit['path[0][alias]']));
     $this->assertText($node1->label(), 'Changed alias works.');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Make sure that previous alias no longer works.
     $this->drupalGet($previous);
     $this->assertNoText($node1->label(), 'Previous alias no longer works.');
-    $this->assertResponse(404);
+    $this->assertSession()->statusCodeEquals(404);
 
     // Create second test node.
     $node2 = $this->drupalCreateNode();
@@ -296,7 +296,7 @@ class PathAliasTest extends PathTestBase {
     // Confirm that the alias no longer works.
     $this->drupalGet($edit['path[0][alias]']);
     $this->assertNoText($node1->label(), 'Alias was successfully deleted.');
-    $this->assertResponse(404);
+    $this->assertSession()->statusCodeEquals(404);
 
     // Create third test node.
     $node3 = $this->drupalCreateNode();
@@ -308,7 +308,7 @@ class PathAliasTest extends PathTestBase {
     // Confirm that the alias was converted to a relative path.
     $this->drupalGet(trim($edit['path[0][alias]'], '/'));
     $this->assertText($node3->label(), 'Alias became relative.');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Create fourth test node.
     $node4 = $this->drupalCreateNode();
@@ -320,7 +320,7 @@ class PathAliasTest extends PathTestBase {
     // Confirm that the alias was converted to a relative path.
     $this->drupalGet(trim($edit['path[0][alias]'], '/'));
     $this->assertText($node4->label(), 'Alias trimmed trailing slash.');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     // Create fifth test node.
     $node5 = $this->drupalCreateNode();
@@ -360,7 +360,7 @@ class PathAliasTest extends PathTestBase {
     $link_href = $link_xpath[0]->getAttribute('href');
     $this->assertEquals($link_href, base_path() . $alias);
     $this->clickLink($node6->getTitle());
-    $this->assertResponse(404);
+    $this->assertSession()->statusCodeEquals(404);
   }
 
   /**
