@@ -17,14 +17,14 @@ class PathTaxonomyTermTest extends PathTestBase {
    *
    * @var array
    */
-  public static $modules = ['taxonomy'];
+  protected static $modules = ['taxonomy'];
 
   /**
    * {@inheritdoc}
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     // Create a Tags vocabulary for the Article node type.
@@ -76,7 +76,7 @@ class PathTaxonomyTermTest extends PathTestBase {
     // Confirm that the old alias no longer works.
     $this->drupalGet(trim($edit['path[0][alias]'], '/'));
     $this->assertNoText($description, 'Old URL alias has been removed after altering.');
-    $this->assertResponse(404, 'Old URL alias returns 404.');
+    $this->assertSession()->statusCodeEquals(404);
 
     // Remove the term's URL alias.
     $edit3 = [];
@@ -86,7 +86,7 @@ class PathTaxonomyTermTest extends PathTestBase {
     // Confirm that the alias no longer works.
     $this->drupalGet(trim($edit2['path[0][alias]'], '/'));
     $this->assertNoText($description, 'Old URL alias has been removed after altering.');
-    $this->assertResponse(404, 'Old URL alias returns 404.');
+    $this->assertSession()->statusCodeEquals(404);
   }
 
 }
