@@ -12,7 +12,7 @@ class MigrateUrlAliasTest extends MigrateUrlAliasTestBase {
   /**
    * {@inheritdoc}
    */
-  public static $modules = [
+  protected static $modules = [
     'path_alias',
     'content_translation',
     'migrate_drupal_multilingual',
@@ -21,7 +21,7 @@ class MigrateUrlAliasTest extends MigrateUrlAliasTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->executeMigrations([
       'd7_node_translation',
