@@ -21,13 +21,6 @@ class AliasManagerTest extends UnitTestCase {
    */
   protected $aliasManager;
 
-  /**
-   * Alias storage.
-   *
-   * @var \Drupal\Core\Path\AliasStorageInterface|\PHPUnit\Framework\MockObject\MockObject
-   */
-  protected $aliasStorage;
-
   /**
    * Alias repository.
    *
@@ -73,7 +66,7 @@ class AliasManagerTest extends UnitTestCase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->aliasRepository = $this->createMock(AliasRepositoryInterface::class);
