@@ -358,15 +358,7 @@ class EntityResource extends ResourceBase implements DependentPluginInterface {
    * {@inheritdoc}
    */
   public function permissions() {
-    // @see https://www.drupal.org/node/2664780
-    if ($this->configFactory->get('rest.settings')->get('bc_entity_resource_permissions')) {
-      // The default Drupal 8.0.x and 8.1.x behavior.
-      return parent::permissions();
-    }
-    else {
-      // The default Drupal 8.2.x behavior.
-      return [];
-    }
+    return [];
   }
 
   /**
@@ -379,13 +371,16 @@ class EntityResource extends ResourceBase implements DependentPluginInterface {
       case 'GET':
         $route->setRequirement('_entity_access', $this->entityType->id() . '.view');
         break;
+
       case 'POST':
         $route->setRequirement('_entity_create_any_access', $this->entityType->id());
         $route->setOption('_ignore_create_bundle_access', TRUE);
         break;
+
       case 'PATCH':
         $route->setRequirement('_entity_access', $this->entityType->id() . '.update');
         break;
+
       case 'DELETE':
         $route->setRequirement('_entity_access', $this->entityType->id() . '.delete');
         break;
