@@ -32,7 +32,7 @@ class SearchBlockTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     // Create and log in user.
@@ -69,14 +69,14 @@ class SearchBlockTest extends BrowserTestBase {
     // Test a normal search via the block form, from the front page.
     $terms = ['keys' => 'test'];
     $this->drupalPostForm('', $terms, t('Search'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText('Your search yielded no results');
 
     // Test a search from the block on a 404 page.
     $this->drupalGet('foo');
-    $this->assertResponse(404);
+    $this->assertSession()->statusCodeEquals(404);
     $this->drupalPostForm(NULL, $terms, t('Search'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText('Your search yielded no results');
 
     $visibility = $block->getVisibility();
@@ -84,7 +84,7 @@ class SearchBlockTest extends BrowserTestBase {
     $block->setVisibilityConfig('request_path', $visibility['request_path']);
 
     $this->drupalPostForm('', $terms, t('Search'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText('Your search yielded no results');
 
     // Confirm that the form submits to the default search page.
@@ -100,7 +100,7 @@ class SearchBlockTest extends BrowserTestBase {
     // Test an empty search via the block form, from the front page.
     $terms = ['keys' => ''];
     $this->drupalPostForm('', $terms, t('Search'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText('Please enter some keywords');
 
     // Confirm that the user is redirected to the search page, when form is
