@@ -46,7 +46,7 @@ class SearchCommentCountToggleTest extends BrowserTestBase {
    */
   protected $searchableNodes;
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->drupalCreateContentType(['type' => 'article', 'name' => 'Article']);
