@@ -18,7 +18,14 @@ class SearchConfigSettingsFormTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected static $modules = ['block', 'dblog', 'node', 'search', 'search_extra_type', 'test_page_test'];
+  protected static $modules = [
+    'block',
+    'dblog',
+    'node',
+    'search',
+    'search_extra_type',
+    'test_page_test',
+  ];
 
   /**
    * {@inheritdoc}
@@ -39,7 +46,7 @@ class SearchConfigSettingsFormTest extends BrowserTestBase {
    */
   protected $searchNode;
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->drupalCreateContentType(['type' => 'page', 'name' => 'Basic page']);
@@ -166,7 +173,7 @@ class SearchConfigSettingsFormTest extends BrowserTestBase {
       // Run a search from the correct search URL.
       $info = $plugin_info[$entity_id];
       $this->drupalGet('search/' . $entity->getPath(), ['query' => ['keys' => $info['keys']]]);
-      $this->assertResponse(200);
+      $this->assertSession()->statusCodeEquals(200);
       $this->assertNoText('no results', $entity->label() . ' search found results');
       $this->assertText($info['text'], 'Correct search text found');
 
@@ -188,7 +195,7 @@ class SearchConfigSettingsFormTest extends BrowserTestBase {
 
       // Try an invalid search path, which should 404.
       $this->drupalGet('search/not_a_plugin_path');
-      $this->assertResponse(404);
+      $this->assertSession()->statusCodeEquals(404);
 
       $entity->disable()->save();
     }
@@ -306,14 +313,14 @@ class SearchConfigSettingsFormTest extends BrowserTestBase {
 
     // Disable the first search page.
     $this->clickLink(t('Disable'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertNoLink(t('Disable'));
     $this->verifySearchPageOperations($first_id, TRUE, TRUE, FALSE, TRUE);
     $this->verifySearchPageOperations($second_id, TRUE, FALSE, FALSE, FALSE);
 
     // Enable the first search page.
     $this->clickLink(t('Enable'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->verifySearchPageOperations($first_id, TRUE, TRUE, TRUE, FALSE);
     $this->verifySearchPageOperations($second_id, TRUE, FALSE, FALSE, FALSE);
 
@@ -331,11 +338,11 @@ class SearchConfigSettingsFormTest extends BrowserTestBase {
   public function testRouteProtection() {
     // Ensure that the enable and disable routes are protected.
     $this->drupalGet('admin/config/search/pages/manage/node_search/enable');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
     $this->drupalGet('admin/config/search/pages/manage/node_search/disable');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
     $this->drupalGet('admin/config/search/pages/manage/node_search/set-default');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
   }
 
   /**
