@@ -16,6 +16,11 @@ class SearchNodeDiacriticsTest extends BrowserTestBase {
    */
   protected static $modules = ['node', 'search'];
 
+  /**
+   * {@inheritdoc}
+   */
+  protected $defaultTheme = 'stark';
+
   /**
    * A user with permission to use advanced search.
    *
@@ -23,7 +28,7 @@ class SearchNodeDiacriticsTest extends BrowserTestBase {
    */
   public $testUser;
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->drupalCreateContentType(['type' => 'page', 'name' => 'Basic page']);
@@ -45,7 +50,6 @@ class SearchNodeDiacriticsTest extends BrowserTestBase {
 
     // Update the search index.
     $this->container->get('plugin.manager.search')->createInstance('node_search')->updateIndex();
-    search_update_totals();
 
     // Refresh variables after the treatment.
     $this->refreshVariables();
