@@ -2,6 +2,8 @@
 
 namespace Drupal\Tests\search\Functional;
 
+use Drupal\Core\Database\Database;
+use Drupal\search\SearchIndexInterface;
 use Drupal\Tests\BrowserTestBase;
 
 /**
@@ -16,6 +18,11 @@ class SearchNodeUpdateAndDeletionTest extends BrowserTestBase {
    */
   protected static $modules = ['node', 'search'];
 
+  /**
+   * {@inheritdoc}
+   */
+  protected $defaultTheme = 'stark';
+
   /**
    * A user with permission to access and search content.
    *
@@ -23,7 +30,7 @@ class SearchNodeUpdateAndDeletionTest extends BrowserTestBase {
    */
   public $testUser;
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->drupalCreateContentType(['type' => 'page', 'name' => 'Basic page']);
@@ -47,7 +54,8 @@ class SearchNodeUpdateAndDeletionTest extends BrowserTestBase {
     $node_search_plugin = $this->container->get('plugin.manager.search')->createInstance('node_search');
     // Update the search index.
     $node_search_plugin->updateIndex();
-    search_update_totals();
+    $search_index = \Drupal::service('search.index');
+    assert($search_index instanceof SearchIndexInterface);
 
     // Search the node to verify it appears in search results
     $edit = ['keys' => 'knights'];
@@ -60,7 +68,6 @@ class SearchNodeUpdateAndDeletionTest extends BrowserTestBase {
 
     // Run indexer again
     $node_search_plugin->updateIndex();
-    search_update_totals();
 
     // Search again to verify the new text appears in test results.
     $edit = ['keys' => 'shrubbery'];
@@ -82,7 +89,6 @@ class SearchNodeUpdateAndDeletionTest extends BrowserTestBase {
     $node_search_plugin = $this->container->get('plugin.manager.search')->createInstance('node_search');
     // Update the search index.
     $node_search_plugin->updateIndex();
-    search_update_totals();
 
     // Search the node to verify it appears in search results
     $edit = ['keys' => 'dragons'];
@@ -90,7 +96,8 @@ class SearchNodeUpdateAndDeletionTest extends BrowserTestBase {
     $this->assertText($node->label());
 
     // Get the node info from the search index tables.
-    $search_index_dataset = db_query("SELECT sid FROM {search_index} WHERE type = 'node_search' AND  word = :word", [':word' => 'dragons'])
+    $connection = Database::getConnection();
+    $search_index_dataset = $connection->query("SELECT sid FROM {search_index} WHERE type = 'node_search' AND  word = :word", [':word' => 'dragons'])
       ->fetchField();
     $this->assertNotEqual($search_index_dataset, FALSE, t('Node info found on the search_index'));
 
@@ -98,7 +105,7 @@ class SearchNodeUpdateAndDeletionTest extends BrowserTestBase {
     $node->delete();
 
     // Check if the node info is gone from the search table.
-    $search_index_dataset = db_query("SELECT sid FROM {search_index} WHERE type = 'node_search' AND  word = :word", [':word' => 'dragons'])
+    $search_index_dataset = $connection->query("SELECT sid FROM {search_index} WHERE type = 'node_search' AND  word = :word", [':word' => 'dragons'])
       ->fetchField();
     $this->assertFalse($search_index_dataset, t('Node info successfully removed from search_index'));
 
