@@ -66,7 +66,7 @@ class SearchNumbersTest extends BrowserTestBase {
    */
   protected $nodes;
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->drupalCreateContentType(['type' => 'page', 'name' => 'Basic page']);
