@@ -33,7 +33,7 @@ class SearchPageTextTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->drupalCreateContentType(['type' => 'page', 'name' => 'Basic page']);
@@ -68,7 +68,7 @@ class SearchPageTextTest extends BrowserTestBase {
     $this->drupalGet('search/node');
     $this->assertText(t('Enter your keywords'));
     $this->assertText(t('Search'));
-    $this->assertTitle(t('Search') . ' | Drupal', 'Search page title is correct');
+    $this->assertTitle('Search | Drupal');
 
     $edit = [];
     $search_terms = 'bike shed ' . $this->randomMachineName();
@@ -77,7 +77,7 @@ class SearchPageTextTest extends BrowserTestBase {
     $this->assertText('search yielded no results');
     $this->assertText(t('Search'));
     $title_source = 'Search for @keywords | Drupal';
-    $this->assertTitle(t($title_source, ['@keywords' => Unicode::truncate($search_terms, 60, TRUE, TRUE)]), 'Search page title is correct');
+    $this->assertTitle('Search for ' . Unicode::truncate($search_terms, 60, TRUE, TRUE) . ' | Drupal');
     $this->assertNoText('Node', 'Erroneous tab and breadcrumb text is not present');
     $this->assertNoText(t('Node'), 'Erroneous translated tab and breadcrumb text is not present');
     $this->assertText(t('Content'), 'Tab and breadcrumb text is present');
@@ -91,7 +91,7 @@ class SearchPageTextTest extends BrowserTestBase {
     $search_terms = 'Every word is like an unnecessary stain on silence and nothingness.';
     $edit['keys'] = $search_terms;
     $this->drupalPostForm('search/node', $edit, t('Search'));
-    $this->assertTitle(t($title_source, ['@keywords' => 'Every word is like an unnecessary stain on silence and…']), 'Search page title is correct');
+    $this->assertTitle('Search for Every word is like an unnecessary stain on silence and… | Drupal');
 
     // Search for a string with a lot of special characters.
     $search_terms = 'Hear nothing > "see nothing" `feel' . " '1982.";
@@ -103,7 +103,7 @@ class SearchPageTextTest extends BrowserTestBase {
     $edit['keys'] = $this->searchingUser->getAccountName();
     $this->drupalPostForm('search/user', $edit, t('Search'));
     $this->assertText(t('Search'));
-    $this->assertTitle(t($title_source, ['@keywords' => Unicode::truncate($this->searchingUser->getAccountName(), 60, TRUE, TRUE)]));
+    $this->assertTitle('Search for ' . Unicode::truncate($this->searchingUser->getAccountName(), 60, TRUE, TRUE) . ' | Drupal');
 
     $this->clickLink('Search help');
     $this->assertText('Search help', 'Correct title is on search help page');
@@ -157,13 +157,13 @@ class SearchPageTextTest extends BrowserTestBase {
     // Test that if you search for a URL with .. in it, you still end up at
     // the search page. See issue https://www.drupal.org/node/890058.
     $this->drupalPostForm('search/node', ['keys' => '../../admin'], t('Search'));
-    $this->assertResponse(200, 'Searching for ../../admin with non-admin user does not lead to a 403 error');
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText('no results', 'Searching for ../../admin with non-admin user gives you a no search results page');
 
     // Test that if you search for a URL starting with "./", you still end up
     // at the search page. See issue https://www.drupal.org/node/1421560.
     $this->drupalPostForm('search/node', ['keys' => '.something'], t('Search'));
-    $this->assertResponse(200, 'Searching for .something does not lead to a 403 error');
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText('no results', 'Searching for .something gives you a no search results page');
   }
 
