@@ -26,7 +26,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
    *
    * @var array
    */
-  public static $modules = ['router_test', 'views', 'block'];
+  protected static $modules = ['router_test', 'views', 'block'];
 
   /**
    * {@inheritdoc}
@@ -36,7 +36,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->drupalPlaceBlock('page_title_block');
@@ -80,11 +80,11 @@ class ShortcutLinksTest extends ShortcutTestBase {
         'link[0][uri]' => $test_path,
       ];
       $this->drupalPostForm('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link', $form_data, t('Save'));
-      $this->assertResponse(200);
+      $this->assertSession()->statusCodeEquals(200);
       $this->assertText(t('Added a shortcut for @title.', ['@title' => $title]));
       $saved_set = ShortcutSet::load($set->id());
       $paths = $this->getShortcutInformation($saved_set, 'link');
-      $this->assertTrue(in_array('internal:' . $test_path, $paths), 'Shortcut created: ' . $test_path);
+      $this->assertContains('internal:' . $test_path, $paths, 'Shortcut created: ' . $test_path);
 
       if (in_array($test_path, $test_cases_non_access)) {
         $this->assertNoLink($title, new FormattableMarkup('Shortcut link %url not accessible on the page.', ['%url' => $test_path]));
@@ -113,7 +113,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
       'link[0][uri]' => '/admin',
     ];
     $this->drupalPostForm('admin/config/user-interface/shortcut/manage/' . $set->id() . '/add-link', $form_data, t('Save'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertRaw(t("The path '@link_path' is inaccessible.", ['@link_path' => '/admin']));
 
     $form_data = [
@@ -136,7 +136,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
       'link[0][uri]' => '/admin',
     ];
     $this->drupalPostForm('admin/config/user-interface/shortcut/manage/' . $edit['id'] . '/add-link', $form_data, t('Save'));
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
   }
 
   /**
@@ -239,7 +239,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
     $this->drupalPostForm('admin/config/user-interface/shortcut/link/' . $shortcut->id(), ['title[0][value]' => $new_link_name], t('Save'));
     $saved_set = ShortcutSet::load($set->id());
     $titles = $this->getShortcutInformation($saved_set, 'title');
-    $this->assertTrue(in_array($new_link_name, $titles), 'Shortcut renamed: ' . $new_link_name);
+    $this->assertContains($new_link_name, $titles, 'Shortcut renamed: ' . $new_link_name);
     $this->assertLink($new_link_name, 0, 'Renamed shortcut link appears on the page.');
     $this->assertText(t('The shortcut @link has been updated.', ['@link' => $new_link_name]));
   }
@@ -258,7 +258,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
     $this->drupalPostForm('admin/config/user-interface/shortcut/link/' . $shortcut->id(), ['title[0][value]' => $shortcut->getTitle(), 'link[0][uri]' => $new_link_path], t('Save'));
     $saved_set = ShortcutSet::load($set->id());
     $paths = $this->getShortcutInformation($saved_set, 'link');
-    $this->assertTrue(in_array('internal:' . $new_link_path, $paths), 'Shortcut path changed: ' . $new_link_path);
+    $this->assertContains('internal:' . $new_link_path, $paths, 'Shortcut path changed: ' . $new_link_path);
     $this->assertLinkByHref($new_link_path, 0, 'Shortcut with new path appears on the page.');
     $this->assertText(t('The shortcut @link has been updated.', ['@link' => $shortcut->getTitle()]));
   }
@@ -269,14 +269,14 @@ class ShortcutLinksTest extends ShortcutTestBase {
   public function testShortcutLinkChangeRoute() {
     $this->drupalLogin($this->rootUser);
     $this->drupalGet('admin/content');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     // Disable the view.
     View::load('content')->disable()->save();
     /** @var \Drupal\Core\Routing\RouteBuilderInterface $router_builder */
     $router_builder = \Drupal::service('router.builder');
     $router_builder->rebuildIfNeeded();
     $this->drupalGet('admin/content');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
   }
 
   /**
@@ -290,7 +290,7 @@ class ShortcutLinksTest extends ShortcutTestBase {
     $this->drupalPostForm('admin/config/user-interface/shortcut/link/' . $shortcut->id() . '/delete', [], 'Delete');
     $saved_set = ShortcutSet::load($set->id());
     $ids = $this->getShortcutInformation($saved_set, 'id');
-    $this->assertFalse(in_array($shortcut->id(), $ids), 'Successfully deleted a shortcut.');
+    $this->assertNotContains($shortcut->id(), $ids, 'Successfully deleted a shortcut.');
 
     // Delete all the remaining shortcut links.
     $storage = \Drupal::entityTypeManager()->getStorage('shortcut');
@@ -355,9 +355,9 @@ class ShortcutLinksTest extends ShortcutTestBase {
     $this->assertNoLink('Shortcuts', 'Shortcut link not found on page.');
 
     // Verify that users without the 'administer site configuration' permission
-    // can't see the cron shortcuts.
+    // can't see the cron shortcuts but can see shortcuts.
     $this->drupalLogin($this->drupalCreateUser(['access toolbar', 'access shortcuts']));
-    $this->assertNoLink('Shortcuts', 'Shortcut link not found on page.');
+    $this->assertLink('Shortcuts');
     $this->assertNoLink('Cron', 'Cron shortcut link not found on page.');
 
     // Verify that users with the 'access shortcuts' permission can see the
@@ -406,17 +406,12 @@ class ShortcutLinksTest extends ShortcutTestBase {
 
     // Verify that set administration pages are inaccessible without the
     // 'access shortcuts' permission.
-    $edit_paths = [
-      'admin/config/user-interface/shortcut/manage/default/customize',
-      'admin/config/user-interface/shortcut/manage/default',
-      'user/' . $noaccess_user->id() . '/shortcuts',
-    ];
-
-    foreach ($edit_paths as $path) {
-      $this->drupalGet($path);
-      $message = new FormattableMarkup('Access is denied on %s', ['%s' => $path]);
-      $this->assertResponse(403, $message);
-    }
+    $this->drupalGet('admin/config/user-interface/shortcut/manage/default/customize');
+    $this->assertSession()->statusCodeEquals(403);
+    $this->drupalGet('admin/config/user-interface/shortcut/manage/default');
+    $this->assertSession()->statusCodeEquals(403);
+    $this->drupalGet('user/' . $noaccess_user->id() . '/shortcuts');
+    $this->assertSession()->statusCodeEquals(403);
   }
 
   /**
