@@ -3,8 +3,8 @@
 namespace Drupal\form_test\EventSubscriber;
 
 use Symfony\Component\EventDispatcher\EventSubscriberInterface;
-use Symfony\Component\HttpKernel\Event\FilterResponseEvent;
-use Symfony\Component\HttpKernel\Event\GetResponseEvent;
+use Symfony\Component\HttpKernel\Event\RequestEvent;
+use Symfony\Component\HttpKernel\Event\ResponseEvent;
 use Symfony\Component\HttpKernel\KernelEvents;
 
 /**
@@ -15,10 +15,10 @@ class FormTestEventSubscriber implements EventSubscriberInterface {
   /**
    * Adds custom attributes to the request object.
    *
-   * @param \Symfony\Component\HttpKernel\Event\GetResponseEvent $event
+   * @param \Symfony\Component\HttpKernel\Event\RequestEvent $event
    *   The kernel request event.
    */
-  public function onKernelRequest(GetResponseEvent $event) {
+  public function onKernelRequest(RequestEvent $event) {
     $request = $event->getRequest();
     $request->attributes->set('custom_attributes', 'custom_value');
     $request->attributes->set('request_attribute', 'request_value');
@@ -27,10 +27,10 @@ class FormTestEventSubscriber implements EventSubscriberInterface {
   /**
    * Adds custom headers to the response.
    *
-   * @param \Symfony\Component\HttpKernel\Event\GetResponseEvent $event
-   *   The kernel request event.
+   * @param \Symfony\Component\HttpKernel\Event\ResponseEvent $event
+   *   The kernel response event.
    */
-  public function onKernelResponse(FilterResponseEvent $event) {
+  public function onKernelResponse(ResponseEvent $event) {
     $response = $event->getResponse();
     $response->headers->set('X-Form-Test-Response-Event', 'invoked');
   }
