@@ -18,14 +18,14 @@ class EntityFormTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['entity_test', 'language'];
+  protected static $modules = ['entity_test', 'language'];
 
   /**
    * {@inheritdoc}
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $web_user = $this->drupalCreateUser(['administer entity_test content', 'view test entity']);
     $this->drupalLogin($web_user);
@@ -62,7 +62,7 @@ class EntityFormTest extends BrowserTestBase {
   public function testEntityFormDisplayAlter() {
     $this->drupalGet('entity_test/add');
     $altered_field = $this->xpath('//input[@name="field_test_text[0][value]" and @size="42"]');
-    $this->assertTrue(count($altered_field) === 1, 'The altered field has the correct size value.');
+    $this->assertCount(1, $altered_field, 'The altered field has the correct size value.');
   }
 
   /**
