@@ -20,7 +20,7 @@ class EntityTranslationFormTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['entity_test', 'language', 'node'];
+  protected static $modules = ['entity_test', 'language', 'node'];
 
   /**
    * {@inheritdoc}
@@ -29,7 +29,7 @@ class EntityTranslationFormTest extends BrowserTestBase {
 
   protected $langcodes;
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     // Enable translations for the test entity type.
     \Drupal::state()->set('entity_test.translation', TRUE);
@@ -100,7 +100,7 @@ class EntityTranslationFormTest extends BrowserTestBase {
 
     // Check to make sure the node was created.
     $node = $this->drupalGetNodeByTitle($edit['title[0][value]']);
-    $this->assertInstanceOf(Node::class, $node, 'Node found in database.');
+    $this->assertInstanceOf(Node::class, $node);
 
     // Make body translatable.
     $field_storage = FieldStorageConfig::loadByName('node', 'body');
