@@ -17,7 +17,7 @@ class MenuAccessTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['block', 'menu_test'];
+  protected static $modules = ['block', 'menu_test'];
 
   /**
    * {@inheritdoc}
@@ -27,7 +27,7 @@ class MenuAccessTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->drupalPlaceBlock('local_tasks_block');
@@ -45,22 +45,22 @@ class MenuAccessTest extends BrowserTestBase {
     $this->assertLink('Test custom route access check');
     // Page is still accessible but there should be no menu link.
     $this->drupalGet('menu_test_access_check_session');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertNoLink('Test custom route access check');
     // Test that page is no more accessible.
     $this->drupalGet('menu_test_access_check_session');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
 
     // Check for access to a restricted local task from a default local task.
     $this->drupalGet('foo/asdf');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertLinkByHref('foo/asdf');
     $this->assertLinkByHref('foo/asdf/b');
     $this->assertNoLinkByHref('foo/asdf/c');
 
     // Attempt to access a restricted local task.
     $this->drupalGet('foo/asdf/c');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
     $elements = $this->xpath('//ul[@class=:class]/li/a[@href=:href]', [
       ':class' => 'tabs primary',
       ':href' => Url::fromRoute('menu_test.router_test1', ['bar' => 'asdf'])->toString(),
