@@ -24,7 +24,7 @@ class DateFormatAccessControlHandlerTest extends KernelTestBase {
    *
    * @var array
    */
-  public static $modules = [
+  protected static $modules = [
     'system',
     'user',
   ];
@@ -39,7 +39,7 @@ class DateFormatAccessControlHandlerTest extends KernelTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->installEntitySchema('date_format');
     $this->installEntitySchema('user');
