@@ -18,7 +18,7 @@ class RssTest extends TaxonomyTestBase {
    *
    * @var array
    */
-  public static $modules = ['node', 'field_ui', 'views'];
+  protected static $modules = ['node', 'field_ui', 'views'];
 
   /**
    * {@inheritdoc}
@@ -39,7 +39,7 @@ class RssTest extends TaxonomyTestBase {
    */
   protected $fieldName;
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->drupalLogin($this->drupalCreateUser(['administer taxonomy', 'bypass node access', 'administer content types', 'administer node display']));
@@ -122,7 +122,7 @@ class RssTest extends TaxonomyTestBase {
 
     // Check that the "Exception value" is disabled by default.
     $this->drupalGet('taxonomy/term/all/feed');
-    $this->assertResponse(404);
+    $this->assertSession()->statusCodeEquals(404);
     // Set the exception value to 'all'.
     $view = Views::getView('taxonomy_term');
     $arguments = $view->getDisplay()->getOption('arguments');
