@@ -23,14 +23,19 @@ class ToolbarMenuTranslationTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['toolbar', 'toolbar_test', 'locale', 'locale_test'];
+  protected static $modules = [
+    'toolbar',
+    'toolbar_test',
+    'locale',
+    'locale_test',
+  ];
 
   /**
    * {@inheritdoc}
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     // Create an administrative user and log it in.
@@ -66,7 +71,7 @@ class ToolbarMenuTranslationTest extends BrowserTestBase {
 
     // Check that the class is on the item before we translate it.
     $xpath = $this->xpath('//a[contains(@class, "icon-system-admin-structure")]');
-    $this->assertEqual(count($xpath), 1, 'The menu item class ok before translation.');
+    $this->assertCount(1, $xpath, 'The menu item class ok before translation.');
 
     // Translate the menu item.
     $menu_item_translated = $this->randomMachineName();
@@ -95,7 +100,7 @@ class ToolbarMenuTranslationTest extends BrowserTestBase {
     // Toolbar icons are included based on the presence of a specific class on
     // the menu item. Ensure that class also exists for a translated menu item.
     $xpath = $this->xpath('//a[contains(@class, "icon-system-admin-structure")]');
-    $this->assertEqual(count($xpath), 1, 'The menu item class is the same.');
+    $this->assertCount(1, $xpath, 'The menu item class is the same.');
   }
 
 }
