@@ -14,28 +14,35 @@ class FileTransferAuthorizeFormTest extends UpdateTestBase {
    *
    * @var array
    */
-  public static $modules = ['update', 'update_test'];
+  protected static $modules = ['update', 'update_test'];
 
   /**
    * {@inheritdoc}
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $admin_user = $this->drupalCreateUser(['administer modules', 'administer software updates', 'administer site configuration']);
     $this->drupalLogin($admin_user);
 
     // Create a local cache so the module is not downloaded from drupal.org.
     $cache_directory = _update_manager_cache_directory(TRUE);
-    $validArchiveFile = __DIR__ . '/../../update_test_new_module/8.x-1.0/update_test_new_module.tar.gz';
-    copy($validArchiveFile, $cache_directory . '/update_test_new_module.tar.gz');
+    foreach (['.tar.gz', '.zip'] as $extension) {
+      $filename = 'update_test_new_module' . $extension;
+      copy(
+        __DIR__ . '/../../update_test_new_module/8.x-1.0/' . $filename,
+        $cache_directory . '/' . $filename
+      );
+    }
   }
 
   /**
    * Tests the Update Manager module upload via authorize.php functionality.
+   *
+   * @dataProvider archiveFileUrlProvider
    */
-  public function testViaAuthorize() {
+  public function testViaAuthorize($url) {
     // Ensure the that we can select which file transfer backend to use.
     \Drupal::state()->set('test_uploaders_via_prompt', TRUE);
 
@@ -44,8 +51,7 @@ class FileTransferAuthorizeFormTest extends UpdateTestBase {
     $this->assertNoText('Update test new module');
 
     $edit = [
-      // This project has been cached in the test's setUp() method.
-      'project_url' => 'https://ftp.drupal.org/files/projects/update_test_new_module.tar.gz',
+      'project_url' => $url,
     ];
     $this->drupalPostForm('admin/modules/install', $edit, t('Install'));
     $edit = [
@@ -60,4 +66,20 @@ class FileTransferAuthorizeFormTest extends UpdateTestBase {
     $this->assertText('Update test new module');
   }
 
+  /**
+   * Data provider method for testViaAuthorize().
+   *
+   * Each of these release URLs has been cached in the setUp() method.
+   */
+  public function archiveFileUrlProvider() {
+    return [
+      'tar.gz' => [
+        'url' => 'https://ftp.drupal.org/files/projects/update_test_new_module.tar.gz',
+      ],
+      'zip' => [
+        'url' => 'https://ftp.drupal.org/files/projects/update_test_new_module.zip',
+      ],
+    ];
+  }
+
 }
