@@ -5,6 +5,7 @@ namespace Drupal\Tests\update\Functional;
 use Drupal\Core\Link;
 use Drupal\Core\Url;
 use Drupal\Core\Utility\ProjectInfo;
+use Drupal\update\UpdateManagerInterface;
 
 /**
  * Tests how the Update Manager module handles contributed modules and themes in
@@ -29,14 +30,20 @@ class UpdateContribTest extends UpdateTestBase {
    *
    * @var array
    */
-  public static $modules = ['update_test', 'update', 'aaa_update_test', 'bbb_update_test', 'ccc_update_test'];
+  protected static $modules = [
+    'update_test',
+    'update',
+    'aaa_update_test',
+    'bbb_update_test',
+    'ccc_update_test',
+  ];
 
   /**
    * {@inheritdoc}
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $admin_user = $this->drupalCreateUser(['administer site configuration']);
     $this->drupalLogin($admin_user);
@@ -516,7 +523,7 @@ class UpdateContribTest extends UpdateTestBase {
     $update_test_config->set('system_info', $system_info)->save();
     $update_status = [
       'aaa_update_test' => [
-        'status' => UPDATE_NOT_SECURE,
+        'status' => UpdateManagerInterface::NOT_SECURE,
       ],
     ];
     $update_test_config->set('update_status', $update_status)->save();
@@ -708,9 +715,13 @@ class UpdateContribTest extends UpdateTestBase {
         'expected_update_message_type' => static::UPDATE_NONE,
         'fixture' => 'sec.8.x-1.2_8.x-2.2',
       ],
+      '8.x-2.0, 8.x-1.2 8.x-2.2' => [
+        'module_patch_version' => '8.x-2.0',
+        'expected_security_releases' => ['8.x-2.2'],
+        'expected_update_message_type' => static::SECURITY_UPDATE_REQUIRED,
+        'fixture' => 'sec.8.x-1.2_8.x-2.2',
+      ],
       // @todo In https://www.drupal.org/node/2865920 add test cases:
-      //   - 8.x-2.0 using fixture 'sec.8.x-1.2_8.x-2.2' to ensure that 8.x-2.2
-      //     is the only security update.
       //   - 8.x-3.0-beta1 using fixture 'sec.8.x-1.2_8.x-2.2' to ensure that
       //     8.x-2.2 is the  only security update.
     ];
@@ -846,7 +857,7 @@ class UpdateContribTest extends UpdateTestBase {
     $update_element = $this->findUpdateElementByLabel($expected_release_title);
     $this->assertTrue($update_element->hasLink($version));
     $compatibility_details = $update_element->find('css', '.project-update__compatibility-details details');
-    $this->assertContains("Requires Drupal core: $expected_range", $compatibility_details->getText());
+    $this->assertStringContainsString("Requires Drupal core: $expected_range", $compatibility_details->getText());
     $details_summary_element = $compatibility_details->find('css', 'summary');
     if ($is_compatible) {
       $download_version = str_replace('.', '-', $version);
