@@ -21,7 +21,7 @@ class UpdateCoreTest extends UpdateTestBase {
    *
    * @var array
    */
-  public static $modules = ['update_test', 'update', 'language', 'block'];
+  protected static $modules = ['update_test', 'update', 'language', 'block'];
 
   /**
    * {@inheritdoc}
@@ -38,7 +38,7 @@ class UpdateCoreTest extends UpdateTestBase {
    */
   protected $updateProject = 'drupal';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $admin_user = $this->drupalCreateUser(['administer site configuration', 'administer modules', 'administer themes']);
     $this->drupalLogin($admin_user);
@@ -98,7 +98,7 @@ class UpdateCoreTest extends UpdateTestBase {
 
     // Ensure that the update check requires a token.
     $this->drupalGet('admin/reports/updates/check');
-    $this->assertResponse(403, 'Accessing admin/reports/updates/check without a CSRF token results in access denied.');
+    $this->assertSession()->statusCodeEquals(403);
 
     foreach ([0, 1] as $minor_version) {
       foreach (['-alpha1', '-beta1', ''] as $extra_version) {
@@ -134,6 +134,7 @@ class UpdateCoreTest extends UpdateTestBase {
               $this->assertRaw('check.svg', 'Check icon was found.');
             }
             break;
+
           case 1:
             // Both stable and unstable releases are available.
             // A stable release is the latest.
@@ -355,6 +356,14 @@ class UpdateCoreTest extends UpdateTestBase {
         'expected_update_message_type' => static::UPDATE_NONE,
         'fixture' => 'sec.0.2-rc2',
       ],
+      // Ensure that 8.0.2 security release is not shown because it is earlier
+      // version than 1.0.
+      '1.0, 0.2 1.2' => [
+        'site_patch_version' => '1.0',
+        'expected_security_releases' => ['1.2', '2.0-rc2'],
+        'expected_update_message_type' => static::SECURITY_UPDATE_REQUIRED,
+        'fixture' => 'sec.0.2-rc2',
+      ],
     ];
     $pre_releases = [
       '2.0-alpha1',
@@ -365,24 +374,25 @@ class UpdateCoreTest extends UpdateTestBase {
       '2.0-rc2',
     ];
 
-    // If the site is on an alpha/beta/RC of an upcoming minor and none of the
-    // alpha/beta/RC versions are marked insecure, no security update should be
-    // required.
     foreach ($pre_releases as $pre_release) {
+      // If the site is on an alpha/beta/RC of an upcoming minor and none of the
+      // alpha/beta/RC versions are marked insecure, no security update should
+      // be required.
       $test_cases["Pre-release:$pre_release, no security update"] = [
         'site_patch_version' => $pre_release,
         'expected_security_releases' => [],
         'expected_update_message_type' => $pre_release === '2.0-rc2' ? static::UPDATE_NONE : static::UPDATE_AVAILABLE,
         'fixture' => 'sec.0.2-rc2-b',
       ];
+      // If the site is on an alpha/beta/RC of an upcoming minor and there is
+      // an RC version with a security update, it should be recommended.
+      $test_cases["Pre-release:$pre_release, security update"] = [
+        'site_patch_version' => $pre_release,
+        'expected_security_releases' => $pre_release === '2.0-rc2' ? [] : ['2.0-rc2'],
+        'expected_update_message_type' => $pre_release === '2.0-rc2' ? static::UPDATE_NONE : static::SECURITY_UPDATE_REQUIRED,
+        'fixture' => 'sec.0.2-rc2',
+      ];
     }
-
-    // @todo In https://www.drupal.org/node/2865920 add test cases:
-    //   - For all pre-releases for 8.2.0 except 8.2.0-rc2 using the
-    //     'sec.0.2-rc2' fixture to ensure that 8.2.0-rc2 is the only security
-    //     update.
-    //   - For 8.1.0 using fixture 'sec.0.2-rc2' to ensure that only security
-    //     updates are 8.1.2 and 8.2.0-rc2.
     return $test_cases;
   }
 
@@ -854,7 +864,7 @@ class UpdateCoreTest extends UpdateTestBase {
    *    'supported_branches' is '8.0.,8.1.'.
    * - drupal.1.0-unsupported.xml
    *    'supported_branches' is '8.1.'.
-   * They both have an '8.0.3' release that that has the 'Release type' value of
+   * They both have an '8.0.3' release that has the 'Release type' value of
    * 'unsupported' and an '8.1.0' release that has the 'Release type' value of
    * 'supported' and is the expected update.
    */
