@@ -16,7 +16,7 @@ class UserAccountLinksTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['menu_ui', 'block', 'test_page_test'];
+  protected static $modules = ['menu_ui', 'block', 'test_page_test'];
 
   /**
    * {@inheritdoc}
@@ -26,7 +26,7 @@ class UserAccountLinksTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->drupalPlaceBlock('system_menu_block:account');
     // Make test-page default.
@@ -51,14 +51,14 @@ class UserAccountLinksTest extends BrowserTestBase {
       ':href' => 'user',
       ':text' => 'My account',
     ]);
-    $this->assertEqual(count($link), 1, 'My account link is in secondary menu.');
+    $this->assertCount(1, $link, 'My account link is in secondary menu.');
 
     $link = $this->xpath('//ul[@class=:menu_class]/li/a[contains(@href, :href) and text()=:text]', [
       ':menu_class' => 'menu',
       ':href' => 'user/logout',
       ':text' => 'Log out',
     ]);
-    $this->assertEqual(count($link), 1, 'Log out link is in secondary menu.');
+    $this->assertCount(1, $link, 'Log out link is in secondary menu.');
 
     // Log out and get the homepage.
     $this->drupalLogout();
@@ -70,7 +70,7 @@ class UserAccountLinksTest extends BrowserTestBase {
       ':href' => 'user/login',
       ':text' => 'Log in',
     ]);
-    $this->assertEqual(count($link), 1, 'Log in link is in secondary menu.');
+    $this->assertCount(1, $link, 'Log in link is in secondary menu.');
   }
 
   /**
@@ -87,7 +87,7 @@ class UserAccountLinksTest extends BrowserTestBase {
       ':href' => 'user',
       ':text' => 'My account',
     ]);
-    $this->assertEqual(count($link), 1, 'My account link is in the secondary menu.');
+    $this->assertCount(1, $link, 'My account link is in the secondary menu.');
 
     // Verify that the 'My account' link is enabled. Do not assume the value of
     // auto-increment is 1. Use XPath to obtain input element id and name using
@@ -109,7 +109,7 @@ class UserAccountLinksTest extends BrowserTestBase {
       ':href' => 'user',
       ':text' => 'My account',
     ]);
-    $this->assertEqual(count($link), 0, 'My account link is not in the secondary menu.');
+    $this->assertCount(0, $link, 'My account link is not in the secondary menu.');
   }
 
   /**
@@ -120,16 +120,16 @@ class UserAccountLinksTest extends BrowserTestBase {
     $title_suffix = ' | Drupal';
 
     $this->drupalGet('user');
-    $this->assertTitle('Log in' . $title_suffix, "Page title of /user is 'Log in'");
+    $this->assertTitle('Log in' . $title_suffix);
 
     $this->drupalGet('user/login');
-    $this->assertTitle('Log in' . $title_suffix, "Page title of /user/login is 'Log in'");
+    $this->assertTitle('Log in' . $title_suffix);
 
     $this->drupalGet('user/register');
-    $this->assertTitle('Create new account' . $title_suffix, "Page title of /user/register is 'Create new account' for anonymous users.");
+    $this->assertTitle('Create new account' . $title_suffix);
 
     $this->drupalGet('user/password');
-    $this->assertTitle('Reset your password' . $title_suffix, "Page title of /user/register is 'Reset your password' for anonymous users.");
+    $this->assertTitle('Reset your password' . $title_suffix);
 
     // Check the page title for registered users is "My Account" in menus.
     $this->drupalLogin($this->drupalCreateUser());
