@@ -31,14 +31,14 @@ class UserAdminLanguageTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['user', 'language', 'language_test'];
+  protected static $modules = ['user', 'language', 'language_test'];
 
   /**
    * {@inheritdoc}
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     // User to add and remove language.
     $this->adminUser = $this->drupalCreateUser(['administer languages', 'access administration pages']);
@@ -81,8 +81,9 @@ class UserAdminLanguageTest extends BrowserTestBase {
   /**
    * Tests that the admin language is configurable only for administrators.
    *
-   * If a user has the permission "access administration pages", they should
-   * be able to see the setting to pick the language they want those pages in.
+   * If a user has the permission "access administration pages" or
+   * "view the administration theme", they should be able to see the setting to
+   * pick the language they want those pages in.
    *
    * If a user does not have that permission, it would confusing for them to
    * have a setting for pages they cannot access, so they should not be able to
@@ -98,6 +99,13 @@ class UserAdminLanguageTest extends BrowserTestBase {
     // Ensure administration pages language setting is visible for admin.
     $this->assertFieldByXPath($this->constructFieldXpath('id', 'edit-preferred-admin-langcode'), NULL, 'Administration pages language selector available for admins.');
 
+    // Ensure administration pages language setting is visible for editors.
+    $editor = $this->drupalCreateUser(['view the administration theme']);
+    $this->drupalLogin($editor);
+    $path = 'user/' . $editor->id() . '/edit';
+    $this->drupalGet($path);
+    $this->assertFieldByXPath($this->constructFieldXpath('id', 'edit-preferred-admin-langcode'), NULL, 'Administration pages language selector available for editors.');
+
     // Ensure administration pages language setting is hidden for non-admins.
     $this->drupalLogin($this->regularUser);
     $path = 'user/' . $this->regularUser->id() . '/edit';
