@@ -23,7 +23,7 @@ class UserAdminTest extends BrowserTestBase {
    *
    * @var array
    */
-  public static $modules = ['taxonomy', 'views'];
+  protected static $modules = ['taxonomy', 'views'];
 
   /**
    * {@inheritdoc}
@@ -76,12 +76,12 @@ class UserAdminTest extends BrowserTestBase {
     // Filter the users by name/email.
     $this->drupalGet('admin/people', ['query' => ['user' => $user_a->getAccountName()]]);
     $result = $this->xpath('//table/tbody/tr');
-    $this->assertEqual(1, count($result), 'Filter by username returned the right amount.');
+    $this->assertCount(1, $result, 'Filter by username returned the right amount.');
     $this->assertEqual($user_a->getAccountName(), $result[0]->find('xpath', '/td[2]/a')->getText(), 'Filter by username returned the right user.');
 
     $this->drupalGet('admin/people', ['query' => ['user' => $user_a->getEmail()]]);
     $result = $this->xpath('//table/tbody/tr');
-    $this->assertEqual(1, count($result), 'Filter by username returned the right amount.');
+    $this->assertCount(1, $result, 'Filter by username returned the right amount.');
     $this->assertEqual($user_a->getAccountName(), $result[0]->find('xpath', '/td[2]/a')->getText(), 'Filter by username returned the right user.');
 
     // Filter the users by permission 'administer taxonomy'.
