@@ -25,7 +25,7 @@ class UserRoleAdminTest extends BrowserTestBase {
    *
    * @var string[]
    */
-  public static $modules = ['block'];
+  protected static $modules = ['block'];
 
   /**
    * {@inheritdoc}
@@ -35,7 +35,7 @@ class UserRoleAdminTest extends BrowserTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->adminUser = $this->drupalCreateUser(['administer permissions', 'administer users']);
     $this->drupalPlaceBlock('local_tasks_block');
@@ -53,7 +53,7 @@ class UserRoleAdminTest extends BrowserTestBase {
       ':classes' => 'tabs primary',
       ':text' => 'Roles',
     ]);
-    $this->assertEqual(count($tabs), 1, 'Found roles tab');
+    $this->assertCount(1, $tabs, 'Found roles tab');
 
     // Test adding a role. (In doing so, we use a role name that happens to
     // correspond to an integer, to test that the role administration pages
@@ -63,7 +63,7 @@ class UserRoleAdminTest extends BrowserTestBase {
     $this->drupalPostForm('admin/people/roles/add', $edit, t('Save'));
     $this->assertRaw(t('Role %label has been added.', ['%label' => 123]));
     $role = Role::load($role_name);
-    $this->assertTrue(is_object($role), 'The role was successfully retrieved from the database.');
+    $this->assertIsObject($role);
 
     // Check that the role was created in site default language.
     $this->assertEqual($role->language()->getId(), $default_langcode);
@@ -93,10 +93,10 @@ class UserRoleAdminTest extends BrowserTestBase {
     // Make sure that the system-defined roles can be edited via the user
     // interface.
     $this->drupalGet('admin/people/roles/manage/' . RoleInterface::ANONYMOUS_ID);
-    $this->assertResponse(200, 'Access granted when trying to edit the built-in anonymous role.');
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertNoText(t('Delete role'), 'Delete button for the anonymous role is not present.');
     $this->drupalGet('admin/people/roles/manage/' . RoleInterface::AUTHENTICATED_ID);
-    $this->assertResponse(200, 'Access granted when trying to edit the built-in authenticated role.');
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertNoText(t('Delete role'), 'Delete button for the authenticated role is not present.');
   }
 
