@@ -19,7 +19,7 @@ class BulkFormTest extends UserTestBase {
    *
    * @var array
    */
-  public static $modules = ['views_ui'];
+  protected static $modules = ['views_ui'];
 
   /**
    * {@inheritdoc}
