@@ -29,7 +29,7 @@ class FilterDateTest extends ViewTestBase {
    *
    * @var array
    */
-  public static $modules = ['node', 'views_ui', 'datetime'];
+  protected static $modules = ['node', 'views_ui', 'datetime'];
 
   /**
    * {@inheritdoc}
@@ -43,7 +43,7 @@ class FilterDateTest extends ViewTestBase {
    */
   public $dateFormatter;
 
-  protected function setUp($import_test_views = TRUE) {
+  protected function setUp($import_test_views = TRUE): void {
     parent::setUp($import_test_views);
     $this->dateFormatter = $this->container->get('date.formatter');
 
@@ -243,18 +243,18 @@ class FilterDateTest extends ViewTestBase {
     $this->drupalGet($path);
     $this->drupalPostForm(NULL, [], 'Apply');
     $results = $this->cssSelect('.view-content .field-content');
-    $this->assertEqual(count($results), 4);
+    $this->assertCount(4, $results);
     $this->drupalPostForm(NULL, ['created' => '1'], 'Apply');
     $results = $this->cssSelect('.view-content .field-content');
-    $this->assertEqual(count($results), 1);
+    $this->assertCount(1, $results);
     $this->assertEqual($results[0]->getText(), $this->nodes[3]->id());
     $this->drupalPostForm(NULL, ['created' => '2'], 'Apply');
     $results = $this->cssSelect('.view-content .field-content');
-    $this->assertEqual(count($results), 1);
+    $this->assertCount(1, $results);
     $this->assertEqual($results[0]->getText(), $this->nodes[3]->id());
     $this->drupalPostForm(NULL, ['created' => '3'], 'Apply');
     $results = $this->cssSelect('.view-content .field-content');
-    $this->assertEqual(count($results), 1);
+    $this->assertCount(1, $results);
     $this->assertEqual($results[0]->getText(), $this->nodes[1]->id());
 
     // Change the filter to a single filter to test the schema when the operator
@@ -271,13 +271,13 @@ class FilterDateTest extends ViewTestBase {
     // Test that the filter works as expected.
     $this->drupalGet($path);
     $results = $this->cssSelect('.view-content .field-content');
-    $this->assertEqual(count($results), 1);
+    $this->assertCount(1, $results);
     $this->assertEqual($results[0]->getText(), $this->nodes[3]->id());
     $this->drupalPostForm(NULL, [
       'created' => $this->dateFormatter->format(250000, 'custom', 'Y-m-d H:i:s'),
     ], 'Apply');
     $results = $this->cssSelect('.view-content .field-content');
-    $this->assertEqual(count($results), 2);
+    $this->assertCount(2, $results);
     $this->assertEqual($results[0]->getText(), $this->nodes[2]->id());
     $this->assertEqual($results[1]->getText(), $this->nodes[3]->id());
   }
