@@ -28,7 +28,7 @@ class PagerTest extends ViewTestBase {
    *
    * @var array
    */
-  public static $modules = ['node', 'views_ui'];
+  protected static $modules = ['node', 'views_ui'];
 
   /**
    * {@inheritdoc}
@@ -167,7 +167,7 @@ class PagerTest extends ViewTestBase {
     }
     $view = Views::getView('test_pager_none');
     $this->executeView($view);
-    $this->assertEqual(count($view->result), 11, 'Make sure that every item is returned in the result');
+    $this->assertCount(11, $view->result, 'Make sure that every item is returned in the result');
 
     // Setup and test a offset.
     $view = Views::getView('test_pager_none');
@@ -181,7 +181,7 @@ class PagerTest extends ViewTestBase {
     $view->display_handler->setOption('pager', $pager);
     $this->executeView($view);
 
-    $this->assertEqual(count($view->result), 8, 'Make sure that every item beside the first three is returned in the result');
+    $this->assertCount(8, $view->result, 'Make sure that every item beside the first three is returned in the result');
 
     // Check some public functions.
     $this->assertFalse($view->pager->usePager());
@@ -215,7 +215,7 @@ class PagerTest extends ViewTestBase {
 
     $view = Views::getView('test_pager_some');
     $this->executeView($view);
-    $this->assertEqual(count($view->result), 5, 'Make sure that only a certain count of items is returned');
+    $this->assertCount(5, $view->result, 'Make sure that only a certain count of items is returned');
 
     // Setup and test a offset.
     $view = Views::getView('test_pager_some');
@@ -229,7 +229,7 @@ class PagerTest extends ViewTestBase {
     ];
     $view->display_handler->setOption('pager', $pager);
     $this->executeView($view);
-    $this->assertEqual(count($view->result), 3, 'Make sure that only a certain count of items is returned');
+    $this->assertCount(3, $view->result, 'Make sure that only a certain count of items is returned');
 
     // Check some public functions.
     $this->assertFalse($view->pager->usePager());
@@ -249,7 +249,7 @@ class PagerTest extends ViewTestBase {
 
     $view = Views::getView('test_pager_full');
     $this->executeView($view);
-    $this->assertEqual(count($view->result), 5, 'Make sure that only a certain count of items is returned');
+    $this->assertCount(5, $view->result, 'Make sure that only a certain count of items is returned');
 
     // Setup and test a offset.
     $view = Views::getView('test_pager_full');
@@ -263,13 +263,13 @@ class PagerTest extends ViewTestBase {
     ];
     $view->display_handler->setOption('pager', $pager);
     $this->executeView($view);
-    $this->assertEqual(count($view->result), 3, 'Make sure that only a certain count of items is returned');
+    $this->assertCount(3, $view->result, 'Make sure that only a certain count of items is returned');
 
     // Test items per page = 0
     $view = Views::getView('test_view_pager_full_zero_items_per_page');
     $this->executeView($view);
 
-    $this->assertEqual(count($view->result), 11, 'All items are return');
+    $this->assertCount(11, $view->result, 'All items are return');
 
     // TODO test number of pages.
 
@@ -288,7 +288,7 @@ class PagerTest extends ViewTestBase {
     $view->display_handler->setOption('pager', $pager);
     $this->executeView($view);
     $this->assertEqual($view->pager->getItemsPerPage(), 0);
-    $this->assertEqual(count($view->result), 11);
+    $this->assertCount(11, $view->result);
 
     // Test pager cache contexts.
     $this->drupalGet('test_pager_full');
