@@ -29,7 +29,7 @@ class StyleTableTest extends ViewTestBase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp($import_test_views = TRUE) {
+  protected function setUp($import_test_views = TRUE): void {
     parent::setUp($import_test_views);
 
     $this->enableViewsTestModule();
@@ -48,6 +48,10 @@ class StyleTableTest extends ViewTestBase {
     $result = $this->xpath('//summary/child::text()');
     $this->assertNotEmpty($result, 'The summary appears on the table.');
     $this->assertEqual(trim($result[0]->getText()), 'summary-text');
+    // Check that the summary has the right accessibility settings.
+    $summary = $this->xpath('//summary')[0];
+    $this->assertTrue($summary->hasAttribute('role'));
+    $this->assertTrue($summary->hasAttribute('aria-expanded'));
 
     $result = $this->xpath('//caption/details/child::text()[normalize-space()]');
     $this->assertNotEmpty($result, 'The table description appears on the table.');
@@ -154,10 +158,10 @@ class StyleTableTest extends ViewTestBase {
 
     // Test that only one of the job columns still shows.
     $result = $this->xpath('//thead/tr/th/a[text()="Job"]');
-    $this->assertEqual(count($result), 1, 'Ensure that empty column header is hidden.');
+    $this->assertCount(1, $result, 'Ensure that empty column header is hidden.');
 
     $result = $this->xpath('//tbody/tr/td[contains(concat(" ", @class, " "), " views-field-job-1 ")]');
-    $this->assertEqual(count($result), 0, 'Ensure the empty table cells are hidden.');
+    $this->assertCount(0, $result, 'Ensure the empty table cells are hidden.');
   }
 
   /**
