@@ -161,6 +161,8 @@ class ViewListBuilder extends ConfigEntityListBuilder {
    */
   public function getDefaultOperations(EntityInterface $entity) {
     $operations = parent::getDefaultOperations($entity);
+    // Remove destination redirect for Edit operation.
+    $operations['edit']['url'] = $entity->toUrl('edit-form');
 
     if ($entity->hasLinkTemplate('duplicate-form')) {
       $operations['duplicate'] = [
