@@ -26,7 +26,7 @@ class DefaultViewsTest extends UITestBase {
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp($import_test_views = TRUE) {
+  protected function setUp($import_test_views = TRUE): void {
     parent::setUp($import_test_views);
 
     $this->placeBlock('page_title_block');
@@ -64,7 +64,7 @@ class DefaultViewsTest extends UITestBase {
     $this->drupalPostForm('admin/structure/views/nojs/display/glossary/page_1/title', $edit, t('Apply'));
     $this->drupalPostForm('admin/structure/views/view/glossary/edit/page_1', [], t('Save'));
     $this->drupalGet('glossary');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText($new_title);
 
     // Save another view in the UI.
@@ -93,7 +93,7 @@ class DefaultViewsTest extends UITestBase {
     $edit = [
       'id' => 'duplicate_of_glossary',
     ];
-    $this->assertTitle(t('Duplicate of @label | @site-name', ['@label' => 'Glossary', '@site-name' => $this->config('system.site')->get('name')]));
+    $this->assertTitle('Duplicate of Glossary | Drupal');
     $this->drupalPostForm(NULL, $edit, t('Duplicate'));
     $this->assertUrl('admin/structure/views/view/duplicate_of_glossary', [], 'The normal duplicating name schema is applied.');
 
@@ -125,9 +125,9 @@ class DefaultViewsTest extends UITestBase {
     // Test the default views disclose no data by default.
     $this->drupalLogout();
     $this->drupalGet('glossary');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
     $this->drupalGet('archive');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
 
     // Test deleting a view.
     $this->drupalLogin($this->fullAdminUser);
@@ -140,7 +140,7 @@ class DefaultViewsTest extends UITestBase {
     $this->assertNoLinkByHref($edit_href);
     // Ensure the view is no longer available.
     $this->drupalGet($edit_href);
-    $this->assertResponse(404);
+    $this->assertSession()->statusCodeEquals(404);
     $this->assertText('Page not found');
 
     // Delete all duplicated Glossary views.
@@ -150,14 +150,14 @@ class DefaultViewsTest extends UITestBase {
     $this->drupalPostForm(NULL, [], t('Delete'));
 
     $this->drupalGet('glossary');
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
 
     $this->drupalGet('admin/structure/views');
     $this->clickViewsOperationLink(t('Delete'), $random_name);
     // Submit the confirmation form.
     $this->drupalPostForm(NULL, [], t('Delete'));
     $this->drupalGet('glossary');
-    $this->assertResponse(404);
+    $this->assertSession()->statusCodeEquals(404);
     $this->assertText('Page not found');
   }
 
@@ -176,25 +176,25 @@ class DefaultViewsTest extends UITestBase {
     $this->drupalGet('admin/structure/views');
 
     $elements = $this->xpath($xpath, $arguments);
-    $this->assertIdentical(count($elements), 0, 'A disabled view is not found in the enabled views table.');
+    $this->assertCount(0, $elements, 'A disabled view is not found in the enabled views table.');
 
     $arguments[':status'] = 'views-list-section disabled';
     $elements = $this->xpath($xpath, $arguments);
-    $this->assertIdentical(count($elements), 1, 'A disabled view is found in the disabled views table.');
+    $this->assertCount(1, $elements, 'A disabled view is found in the disabled views table.');
 
     // Enable the view.
     $this->clickViewsOperationLink(t('Enable'), '/test_view_status/');
 
     $elements = $this->xpath($xpath, $arguments);
-    $this->assertIdentical(count($elements), 0, 'After enabling a view, it is not found in the disabled views table.');
+    $this->assertCount(0, $elements, 'After enabling a view, it is not found in the disabled views table.');
 
     $arguments[':status'] = 'views-list-section enabled';
     $elements = $this->xpath($xpath, $arguments);
-    $this->assertIdentical(count($elements), 1, 'After enabling a view, it is found in the enabled views table.');
+    $this->assertCount(1, $elements, 'After enabling a view, it is found in the enabled views table.');
 
     // Attempt to disable the view by path directly, with no token.
     $this->drupalGet('admin/structure/views/view/test_view_status/disable');
-    $this->assertResponse(403);
+    $this->assertSession()->statusCodeEquals(403);
   }
 
   /**
