@@ -25,7 +25,7 @@ class DisplayTest extends UITestBase {
    *
    * @var array
    */
-  public static $modules = ['contextual'];
+  protected static $modules = ['contextual'];
 
   /**
    * {@inheritdoc}
