@@ -14,7 +14,7 @@ class OverrideDisplaysTest extends UITestBase {
    */
   protected $defaultTheme = 'stark';
 
-  protected function setUp($import_test_views = TRUE) {
+  protected function setUp($import_test_views = TRUE): void {
     parent::setUp($import_test_views);
 
     $this->drupalPlaceBlock('page_title_block');
@@ -51,7 +51,7 @@ class OverrideDisplaysTest extends UITestBase {
 
     // Make sure the title appears in the page.
     $this->drupalGet($view_path);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText($original_title);
 
     // Confirm that the view block is available in the block administration UI.
@@ -74,7 +74,7 @@ class OverrideDisplaysTest extends UITestBase {
     $this->drupalPostForm("admin/structure/views/nojs/display/{$view['id']}/page_1/title", $edit, t('Apply'));
     $this->drupalPostForm("admin/structure/views/view/{$view['id']}/edit/page_1", [], t('Save'));
     $this->drupalGet($view_path);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText($new_title);
     $this->assertText($original_title);
   }
@@ -106,11 +106,11 @@ class OverrideDisplaysTest extends UITestBase {
     // Make sure that the feed, page and block all start off with the correct
     // titles.
     $this->drupalGet($view['page[path]']);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText($view['page[title]']);
     $this->assertNoText($view['block[title]']);
     $this->drupalGet($view['page[feed_properties][path]']);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText($view['page[title]']);
     $this->assertNoText($view['block[title]']);
 
@@ -142,12 +142,12 @@ class OverrideDisplaysTest extends UITestBase {
     $this->drupalPostForm("admin/structure/views/nojs/display/{$view['id']}/page_1/title", $edit, t('Apply'));
     $this->drupalPostForm("admin/structure/views/view/{$view['id']}/edit/page_1", [], t('Save'));
     $this->drupalGet($view['page[path]']);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText($new_default_title);
     $this->assertNoText($view['page[title]']);
     $this->assertNoText($view['block[title]']);
     $this->drupalGet($view['page[feed_properties][path]']);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText($new_default_title);
     $this->assertNoText($view['page[title]']);
     $this->assertNoText($view['block[title]']);
@@ -163,10 +163,10 @@ class OverrideDisplaysTest extends UITestBase {
     $this->drupalPostForm("admin/structure/views/nojs/display/{$view['id']}/block_1/title", $edit, t('Apply'));
     $this->drupalPostForm("admin/structure/views/view/{$view['id']}/edit/block_1", [], t('Save'));
     $this->drupalGet($view['page[path]']);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText($new_default_title);
     $this->drupalGet($view['page[feed_properties][path]']);
-    $this->assertResponse(200);
+    $this->assertSession()->statusCodeEquals(200);
     $this->assertText($new_default_title);
     $this->assertNoText($new_block_title);
     $this->drupalGet('');
