@@ -36,9 +36,9 @@ class ViewsUITourTest extends TourTestBase {
    *
    * @var array
    */
-  public static $modules = ['views_ui', 'tour', 'language', 'locale'];
+  protected static $modules = ['views_ui', 'tour', 'language', 'locale'];
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->adminUser = $this->drupalCreateUser(['administer views', 'access tour']);
     $this->drupalLogin($this->adminUser);
