@@ -2,7 +2,6 @@
 
 namespace Drupal\Tests\views_ui\Kernel;
 
-use Drupal\Component\Render\FormattableMarkup;
 use Drupal\Tests\views\Kernel\ViewsKernelTestBase;
 use Drupal\views_ui\Controller\ViewsUIController;
 use Drupal\Component\Utility\Html;
@@ -20,7 +19,7 @@ class TagTest extends ViewsKernelTestBase {
    *
    * @var array
    */
-  public static $modules = ['views', 'views_ui', 'user'];
+  protected static $modules = ['views', 'views_ui', 'user'];
 
   /**
    * Tests the views_ui_autocomplete_tag function.
@@ -43,30 +42,30 @@ class TagTest extends ViewsKernelTestBase {
     $request->query->set('q', 'autocomplete_tag_test');
     $result = $controller->autocompleteTag($request);
     $matches = (array) json_decode($result->getContent(), TRUE);
-    $this->assertEqual(count($matches), 10, 'Make sure the maximum amount of tag results is 10.');
+    $this->assertCount(10, $matches, 'Make sure the maximum amount of tag results is 10.');
 
     // Make sure the returned array has the proper format.
     $suggestions = array_map(function ($tag) {
       return ['value' => $tag, 'label' => Html::escape($tag)];
     }, $tags);
     foreach ($matches as $match) {
-      $this->assertTrue(in_array($match, $suggestions), 'Make sure the returned array has the proper format.');
+      $this->assertContains($match, $suggestions, 'Make sure the returned array has the proper format.');
     }
 
     // Make sure that matching by a certain prefix works.
     $request->query->set('q', 'autocomplete_tag_test_even');
     $result = $controller->autocompleteTag($request);
     $matches = (array) json_decode($result->getContent(), TRUE);
-    $this->assertEqual(count($matches), 8, 'Make sure that only a subset is returned.');
+    $this->assertCount(8, $matches, 'Make sure that only a subset is returned.');
     foreach ($matches as $tag) {
-      $this->assertTrue(array_search($tag['value'], $tags) !== FALSE, new FormattableMarkup('Make sure the returned tag @tag actually exists.', ['@tag' => $tag['value']]));
+      $this->assertContains($tag['value'], $tags);
     }
 
     // Make sure an invalid result doesn't return anything.
     $request->query->set('q', $this->randomMachineName());
     $result = $controller->autocompleteTag($request);
     $matches = (array) json_decode($result->getContent());
-    $this->assertEqual(count($matches), 0, "Make sure an invalid tag doesn't return anything.");
+    $this->assertCount(0, $matches, "Make sure an invalid tag doesn't return anything.");
   }
 
 }
