@@ -11,6 +11,11 @@ use Drupal\Tests\BrowserTestBase;
  */
 class GetTestMethodCallerTest extends BrowserTestBase {
 
+  /**
+   * {@inheritdoc}
+   */
+  protected $defaultTheme = 'stark';
+
   /**
    * Tests BrowserTestBase::getTestMethodCaller().
    */
@@ -18,7 +23,7 @@ class GetTestMethodCallerTest extends BrowserTestBase {
     $method_caller = $this->getTestMethodCaller();
     $expected = [
       'file' => __FILE__,
-      'line' => 18,
+      'line' => 23,
       'function' => __CLASS__ . '->' . __FUNCTION__ . '()',
       'class' => BrowserTestBase::class,
       'object' => $this,
