@@ -15,7 +15,7 @@ class EntityViewModeHalJsonBasicAuthTest extends EntityViewModeResourceTestBase
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['hal', 'basic_auth'];
+  protected static $modules = ['hal', 'basic_auth'];
 
   /**
    * {@inheritdoc}
