@@ -14,7 +14,7 @@ class BaseFieldOverrideJsonBasicAuthTest extends BaseFieldOverrideResourceTestBa
   /**
    * {@inheritdoc}
    */
-  public static $modules = ['basic_auth'];
+  protected static $modules = ['basic_auth'];
 
   /**
    * {@inheritdoc}
