@@ -54,39 +54,37 @@ class UpsertTest extends DatabaseTestBase {
   }
 
   /**
-   * Tests that we can upsert records with a special named column.
+   * Confirms that we can upsert records with keywords successfully.
    */
-  public function testSpecialColumnUpsert() {
-    $num_records_before = $this->connection->query('SELECT COUNT(*) FROM {test_special_columns}')->fetchField();
-    $upsert = $this->connection->upsert('test_special_columns')
+  public function testUpsertWithKeywords() {
+    $num_records_before = $this->connection->query('SELECT COUNT(*) FROM {select}')->fetchField();
+
+    $upsert = $this->connection->upsert('select')
       ->key('id')
-      ->fields(['id', 'offset', 'function']);
+      ->fields(['id', 'update']);
 
     // Add a new row.
     $upsert->values([
       'id' => 2,
-      'offset' => 'Offset 2',
-      'function' => 'Function 2',
+      'update' => 'Update value 2',
     ]);
 
     // Update an existing row.
     $upsert->values([
       'id' => 1,
-      'offset' => 'Offset 1 updated',
-      'function' => 'Function 1 updated',
+      'update' => 'Update value 1 updated',
     ]);
 
     $upsert->execute();
-    $num_records_after = $this->connection->query('SELECT COUNT(*) FROM {test_special_columns}')->fetchField();
+
+    $num_records_after = $this->connection->query('SELECT COUNT(*) FROM {select}')->fetchField();
     $this->assertEquals($num_records_before + 1, $num_records_after, 'Rows were inserted and updated properly.');
 
-    $record = $this->connection->query('SELECT * FROM {test_special_columns} WHERE id = :id', [':id' => 1])->fetch();
-    $this->assertEquals($record->offset, 'Offset 1 updated');
-    $this->assertEquals($record->function, 'Function 1 updated');
+    $record = $this->connection->query('SELECT * FROM {select} WHERE id = :id', [':id' => 1])->fetch();
+    $this->assertEquals('Update value 1 updated', $record->update);
 
-    $record = $this->connection->query('SELECT * FROM {test_special_columns} WHERE id = :id', [':id' => 2])->fetch();
-    $this->assertEquals($record->offset, 'Offset 2');
-    $this->assertEquals($record->function, 'Function 2');
+    $record = $this->connection->query('SELECT * FROM {select} WHERE id = :id', [':id' => 2])->fetch();
+    $this->assertEquals('Update value 2', $record->update);
   }
 
 }
