@@ -21,7 +21,7 @@ class TempStoreDatabaseTest extends KernelTestBase {
    *
    * @var array
    */
-  public static $modules = ['system'];
+  protected static $modules = ['system'];
 
   /**
    * A key/value store factory.
@@ -44,7 +44,7 @@ class TempStoreDatabaseTest extends KernelTestBase {
    */
   protected $objects = [];
 
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     // Install system tables to test the key/value storage without installing a
@@ -107,7 +107,7 @@ class TempStoreDatabaseTest extends KernelTestBase {
     $this->assertIdenticalObject($this->objects[2], $stores[1]->get($key));
 
     // This user should be allowed to get, update, delete.
-    $this->assertTrue($stores[0]->getIfOwner($key) instanceof \stdClass);
+    $this->assertInstanceOf(\stdClass::class, $stores[0]->getIfOwner($key));
     $this->assertTrue($stores[0]->setIfOwner($key, $this->objects[1]));
     $this->assertTrue($stores[0]->deleteIfOwner($key));
 
