@@ -2,7 +2,10 @@
 
 namespace Drupal\Tests;
 
+use Drupal\Composer\Plugin\VendorHardening\Config;
+use Drupal\Core\Composer\Composer;
 use Drupal\Tests\Composer\ComposerIntegrationTrait;
+use Symfony\Component\Yaml\Yaml;
 
 /**
  * Tests Composer integration.
@@ -20,6 +23,17 @@ class ComposerIntegrationTest extends UnitTestCase {
     $content_hash = self::getContentHash(file_get_contents($this->root . '/composer.json'));
     $lock = json_decode(file_get_contents($this->root . '/composer.lock'), TRUE);
     $this->assertSame($content_hash, $lock['content-hash']);
+
+    // @see \Composer\Repository\PathRepository::initialize()
+    $core_content_hash = sha1(file_get_contents($this->root . '/core/composer.json') . serialize([]));
+    $core_lock_file_hash = '';
+    foreach ($lock['packages'] as $package) {
+      if ($package['name'] === 'drupal/core') {
+        $core_lock_file_hash = $package['dist']['reference'];
+        break;
+      }
+    }
+    $this->assertSame($core_content_hash, $core_lock_file_hash);
   }
 
   /**
@@ -43,7 +57,7 @@ class ComposerIntegrationTest extends UnitTestCase {
         if (strpos($dependency, 'symfony/') === 0) {
           continue;
         }
-        $this->assertFalse(strpos($version, '~'), "Dependency $dependency in $path contains a tilde, use a caret.");
+        $this->assertStringNotContainsString('~', $version, "Dependency $dependency in $path contains a tilde, use a caret.");
       }
     }
   }
@@ -84,9 +98,18 @@ class ComposerIntegrationTest extends UnitTestCase {
     $discard = ['.', '..'];
     foreach ($folders as $file_name) {
       if ((!in_array($file_name, $discard)) && is_dir($module_path . '/' . $file_name)) {
+        // Skip any modules marked as hidden.
+        $info_yml = $module_path . '/' . $file_name . '/' . $file_name . '.info.yml';
+        if (file_exists($info_yml)) {
+          $info = Yaml::parseFile($info_yml);
+          if (!empty($info['hidden'])) {
+            continue;
+          }
+        }
         $module_names[] = $file_name;
       }
     }
+    $this->assertNotEmpty($module_names);
 
     // Assert that each core module has a corresponding 'replace' in
     // composer.json.
@@ -220,4 +243,36 @@ class ComposerIntegrationTest extends UnitTestCase {
   }
   // @codingStandardsIgnoreEnd
 
+  /**
+   * Tests the vendor cleanup utilities do not have obsolete packages listed.
+   *
+   * @dataProvider providerTestVendorCleanup
+   */
+  public function testVendorCleanup($class, $property) {
+    $lock = json_decode(file_get_contents($this->root . '/composer.lock'), TRUE);
+    $packages = [];
+    foreach (array_merge($lock['packages'], $lock['packages-dev']) as $package) {
+      $packages[] = $package['name'];
+    }
+
+    $reflection = new \ReflectionProperty($class, $property);
+    $reflection->setAccessible(TRUE);
+    $config = $reflection->getValue();
+    foreach (array_keys($config) as $package) {
+      $this->assertContains(strtolower($package), $packages);
+    }
+  }
+
+  /**
+   * Data provider for the vendor cleanup utility classes.
+   *
+   * @return array[]
+   */
+  public function providerTestVendorCleanup() {
+    return [
+      [Composer::class, 'packageToCleanup'],
+      [Config::class, 'defaultConfig'],
+    ];
+  }
+
 }
