@@ -2,6 +2,7 @@
 
 namespace Drupal\Tests\Core\Command;
 
+use Drupal\Core\Database\Driver\sqlite\Install\Tasks;
 use Drupal\Core\Test\TestDatabase;
 use Drupal\Tests\BrowserTestBase;
 use GuzzleHttp\Client;
@@ -18,6 +19,7 @@ use Symfony\Component\Process\Process;
  *
  * @runTestsInSeparateProcesses
  * @preserveGlobalState disabled
+ * @requires extension pdo_sqlite
  *
  * @group Command
  */
@@ -47,23 +49,24 @@ class QuickStartTest extends TestCase {
   /**
    * {@inheritdoc}
    */
-  public function setUp() {
+  public function setUp(): void {
     parent::setUp();
     $php_executable_finder = new PhpExecutableFinder();
     $this->php = $php_executable_finder->find();
-    $this->root = dirname(dirname(substr(__DIR__, 0, -strlen(__NAMESPACE__))));
+    $this->root = dirname(substr(__DIR__, 0, -strlen(__NAMESPACE__)), 2);
     chdir($this->root);
     if (!is_writable("{$this->root}/sites/simpletest")) {
       $this->markTestSkipped('This test requires a writable sites/simpletest directory');
     }
     // Get a lock and a valid site path.
     $this->testDb = new TestDatabase();
+    include $this->root . '/core/includes/bootstrap.inc';
   }
 
   /**
    * {@inheritdoc}
    */
-  public function tearDown() {
+  public function tearDown(): void {
     if ($this->testDb) {
       $test_site_directory = $this->root . DIRECTORY_SEPARATOR . $this->testDb->getTestSitePath();
       if (file_exists($test_site_directory)) {
@@ -83,6 +86,13 @@ class QuickStartTest extends TestCase {
    * Tests the quick-start command.
    */
   public function testQuickStartCommand() {
+    if (version_compare(phpversion(), DRUPAL_MINIMUM_SUPPORTED_PHP) < 0) {
+      $this->markTestSkipped();
+    }
+    if (version_compare(\SQLite3::version()['versionString'], Tasks::SQLITE_MINIMUM_VERSION) < 0) {
+      $this->markTestSkipped();
+    }
+
     // Install a site using the standard profile to ensure the one time login
     // link generation works.
 
@@ -95,7 +105,6 @@ class QuickStartTest extends TestCase {
       '--suppress-login',
     ];
     $process = new Process($install_command, NULL, ['DRUPAL_DEV_SITE_PATH' => $this->testDb->getTestSitePath()]);
-    $process->inheritEnvironmentVariables();
     $process->setTimeout(500);
     $process->start();
     $guzzle = new Client();
@@ -109,15 +118,14 @@ class QuickStartTest extends TestCase {
       sleep(1);
     }
     // The progress bar uses STDERR to write messages.
-    $this->assertContains('Congratulations, you installed Drupal!', $process->getErrorOutput());
+    $this->assertStringContainsString('Congratulations, you installed Drupal!', $process->getErrorOutput());
     $this->assertNotFalse($port, "Web server running on port $port");
 
     // Give the server a couple of seconds to be ready.
     sleep(2);
-    $this->assertContains("127.0.0.1:$port/user/reset/1/", $process->getOutput());
+    $this->assertStringContainsString("127.0.0.1:$port/user/reset/1/", $process->getOutput());
 
     // Generate a cookie so we can make a request against the installed site.
-    include $this->root . '/core/includes/bootstrap.inc';
     define('DRUPAL_TEST_IN_CHILD_SITE', FALSE);
     chmod($this->testDb->getTestSitePath(), 0755);
     $cookieJar = CookieJar::fromArray([
@@ -126,7 +134,40 @@ class QuickStartTest extends TestCase {
 
     $response = $guzzle->get('http://127.0.0.1:' . $port, ['cookies' => $cookieJar]);
     $content = (string) $response->getBody();
-    $this->assertContains('Test site ' . $this->testDb->getDatabasePrefix(), $content);
+    $this->assertStringContainsString('Test site ' . $this->testDb->getDatabasePrefix(), $content);
+
+    // Stop the web server.
+    $process->stop();
+  }
+
+  /**
+   * Tests that the installer throws a requirement error on older PHP versions.
+   */
+  public function testPhpRequirement() {
+    if (version_compare(phpversion(), DRUPAL_MINIMUM_SUPPORTED_PHP) >= 0) {
+      $this->markTestSkipped();
+    }
+
+    $install_command = [
+      $this->php,
+      'core/scripts/drupal',
+      'quick-start',
+      'standard',
+      "--site-name='Test site {$this->testDb->getDatabasePrefix()}'",
+      '--suppress-login',
+    ];
+    $process = new Process($install_command, NULL, ['DRUPAL_DEV_SITE_PATH' => $this->testDb->getTestSitePath()]);
+    $process->setTimeout(500);
+    $process->start();
+    while ($process->isRunning()) {
+      // Wait for more output.
+      sleep(1);
+    }
+
+    $error_output = $process->getErrorOutput();
+    $this->assertStringContainsString('Your PHP installation is too old.', $error_output);
+    $this->assertStringContainsString('Drupal requires at least PHP', $error_output);
+    $this->assertStringContainsString(DRUPAL_MINIMUM_SUPPORTED_PHP, $error_output);
 
     // Stop the web server.
     $process->stop();
@@ -136,6 +177,13 @@ class QuickStartTest extends TestCase {
    * Tests the quick-start commands.
    */
   public function testQuickStartInstallAndServerCommands() {
+    if (version_compare(phpversion(), DRUPAL_MINIMUM_SUPPORTED_PHP) < 0) {
+      $this->markTestSkipped();
+    }
+    if (version_compare(\SQLite3::version()['versionString'], Tasks::SQLITE_MINIMUM_VERSION) < 0) {
+      $this->markTestSkipped();
+    }
+
     // Install a site.
     $install_command = [
       $this->php,
@@ -145,11 +193,10 @@ class QuickStartTest extends TestCase {
       "--site-name='Test site {$this->testDb->getDatabasePrefix()}'",
     ];
     $install_process = new Process($install_command, NULL, ['DRUPAL_DEV_SITE_PATH' => $this->testDb->getTestSitePath()]);
-    $install_process->inheritEnvironmentVariables();
     $install_process->setTimeout(500);
     $result = $install_process->run();
     // The progress bar uses STDERR to write messages.
-    $this->assertContains('Congratulations, you installed Drupal!', $install_process->getErrorOutput());
+    $this->assertStringContainsString('Congratulations, you installed Drupal!', $install_process->getErrorOutput());
     $this->assertSame(0, $result);
 
     // Run the PHP built-in webserver.
@@ -160,7 +207,6 @@ class QuickStartTest extends TestCase {
       '--suppress-login',
     ];
     $server_process = new Process($server_command, NULL, ['DRUPAL_DEV_SITE_PATH' => $this->testDb->getTestSitePath()]);
-    $server_process->inheritEnvironmentVariables();
     $server_process->start();
     $guzzle = new Client();
     $port = FALSE;
@@ -173,14 +219,13 @@ class QuickStartTest extends TestCase {
       sleep(1);
     }
     $this->assertEquals('', $server_process->getErrorOutput());
-    $this->assertContains("127.0.0.1:$port/user/reset/1/", $server_process->getOutput());
+    $this->assertStringContainsString("127.0.0.1:$port/user/reset/1/", $server_process->getOutput());
     $this->assertNotFalse($port, "Web server running on port $port");
 
     // Give the server a couple of seconds to be ready.
     sleep(2);
 
     // Generate a cookie so we can make a request against the installed site.
-    include $this->root . '/core/includes/bootstrap.inc';
     define('DRUPAL_TEST_IN_CHILD_SITE', FALSE);
     chmod($this->testDb->getTestSitePath(), 0755);
     $cookieJar = CookieJar::fromArray([
@@ -189,7 +234,7 @@ class QuickStartTest extends TestCase {
 
     $response = $guzzle->get('http://127.0.0.1:' . $port, ['cookies' => $cookieJar]);
     $content = (string) $response->getBody();
-    $this->assertContains('Test site ' . $this->testDb->getDatabasePrefix(), $content);
+    $this->assertStringContainsString('Test site ' . $this->testDb->getDatabasePrefix(), $content);
 
     // Try to re-install over the top of an existing site.
     $install_command = [
@@ -200,16 +245,15 @@ class QuickStartTest extends TestCase {
       "--site-name='Test another site {$this->testDb->getDatabasePrefix()}'",
     ];
     $install_process = new Process($install_command, NULL, ['DRUPAL_DEV_SITE_PATH' => $this->testDb->getTestSitePath()]);
-    $install_process->inheritEnvironmentVariables();
     $install_process->setTimeout(500);
     $result = $install_process->run();
-    $this->assertContains('Drupal is already installed.', $install_process->getOutput());
+    $this->assertStringContainsString('Drupal is already installed.', $install_process->getOutput());
     $this->assertSame(0, $result);
 
     // Ensure the site name has not changed.
     $response = $guzzle->get('http://127.0.0.1:' . $port, ['cookies' => $cookieJar]);
     $content = (string) $response->getBody();
-    $this->assertContains('Test site ' . $this->testDb->getDatabasePrefix(), $content);
+    $this->assertStringContainsString('Test site ' . $this->testDb->getDatabasePrefix(), $content);
 
     // Stop the web server.
     $server_process->stop();
@@ -229,9 +273,8 @@ class QuickStartTest extends TestCase {
       "--site-name='Test site {$this->testDb->getDatabasePrefix()}' --suppress-login",
     ];
     $process = new Process($install_command, NULL, ['DRUPAL_DEV_SITE_PATH' => $this->testDb->getTestSitePath()]);
-    $process->inheritEnvironmentVariables();
     $process->run();
-    $this->assertContains('\'umami\' is not a valid install profile. Did you mean \'demo_umami\'?', $process->getErrorOutput());
+    $this->assertStringContainsString('\'umami\' is not a valid install profile. Did you mean \'demo_umami\'?', $process->getErrorOutput());
   }
 
   /**
@@ -245,9 +288,8 @@ class QuickStartTest extends TestCase {
       '--suppress-login',
     ];
     $server_process = new Process($server_command, NULL, ['DRUPAL_DEV_SITE_PATH' => $this->testDb->getTestSitePath()]);
-    $server_process->inheritEnvironmentVariables();
     $server_process->run();
-    $this->assertContains('No installation found. Use the \'install\' command.', $server_process->getErrorOutput());
+    $this->assertStringContainsString('No installation found. Use the \'install\' command.', $server_process->getErrorOutput());
   }
 
   /**
@@ -267,7 +309,7 @@ class QuickStartTest extends TestCase {
    *   TRUE for success or if path does not exist, FALSE in the event of an
    *   error.
    *
-   * @see file_unmanaged_delete_recursive()
+   * @see \Drupal\Core\File\FileSystemInterface::deleteRecursive()
    */
   protected function fileUnmanagedDeleteRecursive($path, $callback = NULL) {
     if (isset($callback)) {
