@@ -84,7 +84,7 @@ class KeyValueEntityStorageTest extends UnitTestCase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
     $this->entityType = $this->createMock('Drupal\Core\Entity\EntityTypeInterface');
   }
