@@ -187,7 +187,7 @@ abstract class FormTestBase extends UnitTestCase {
       ->setConstructorArgs([$this->requestStack, $this->urlGenerator])
       ->setMethods(['batchGet', 'drupalInstallationAttempted'])
       ->getMock();
-    $this->root = dirname(dirname(substr(__DIR__, 0, -strlen(__NAMESPACE__))));
+    $this->root = dirname(substr(__DIR__, 0, -strlen(__NAMESPACE__)), 2);
 
     $this->formBuilder = new FormBuilder($this->formValidator, $this->formSubmitter, $this->formCache, $this->moduleHandler, $this->eventDispatcher, $this->requestStack, $this->classResolver, $this->elementInfo, $this->themeManager, $this->csrfToken);
   }
