@@ -35,7 +35,7 @@ class ChainResponsePolicyTest extends UnitTestCase {
    */
   protected $response;
 
-  protected function setUp() {
+  protected function setUp(): void {
     $this->policy = new ChainResponsePolicy();
     $this->response = new Response();
     $this->request = new Request();
