@@ -10,6 +10,7 @@ use Drupal\Core\Template\AttributeString;
 use Drupal\Core\Template\Loader\StringLoader;
 use Drupal\Tests\UnitTestCase;
 use Drupal\Component\Render\MarkupInterface;
+use Twig\Environment;
 
 /**
  * @coversDefaultClass \Drupal\Core\Template\Attribute
@@ -265,7 +266,7 @@ class AttributeTest extends UnitTestCase {
    */
   public function testTwigAddRemoveClasses($template, $expected, $seed_attributes = []) {
     $loader = new StringLoader();
-    $twig = new \Twig_Environment($loader);
+    $twig = new Environment($loader);
     $data = ['attributes' => new Attribute($seed_attributes)];
     $result = $twig->createTemplate($template)->render($data);
     $this->assertEquals($expected, $result);
@@ -348,7 +349,7 @@ class AttributeTest extends UnitTestCase {
     $this->assertID('example-id', $html);
     $this->assertNoID('example-id2', $html);
 
-    $this->assertTrue(strpos($html, 'enabled') !== FALSE);
+    $this->assertStringContainsString('enabled', $html);
   }
 
   /**
