@@ -3,6 +3,7 @@
 namespace Drupal\Tests\Core\Utility;
 
 use Drupal\Component\Render\MarkupInterface;
+use Drupal\Core\GeneratedButton;
 use Drupal\Core\GeneratedNoLink;
 use Drupal\Core\GeneratedUrl;
 use Drupal\Core\Language\Language;
@@ -67,7 +68,7 @@ class LinkGeneratorTest extends UnitTestCase {
   /**
    * {@inheritdoc}
    */
-  protected function setUp() {
+  protected function setUp(): void {
     parent::setUp();
 
     $this->urlGenerator = $this->getMockBuilder('\Drupal\Core\Routing\UrlGenerator')
@@ -169,7 +170,7 @@ class LinkGeneratorTest extends UnitTestCase {
     $url->setOption('set_active_class', TRUE);
 
     $result = $this->linkGenerator->generate('Test', $url);
-    $this->assertTrue($result instanceof GeneratedNoLink);
+    $this->assertInstanceOf(GeneratedNoLink::class, $result);
     $this->assertSame('<span>Test</span>', (string) $result);
   }
 
@@ -199,6 +200,26 @@ class LinkGeneratorTest extends UnitTestCase {
     $this->assertSame('<a href="">Test</a>', (string) $result);
   }
 
+  /**
+   * Tests the generate() method with the <button> route.
+   *
+   * @covers ::generate
+   */
+  public function testGenerateButton() {
+    $this->urlGenerator->expects($this->never())
+      ->method('generateFromRoute');
+    $this->moduleHandler->expects($this->once())
+      ->method('alter')
+      ->with('link', $this->isType('array'));
+
+    $url = Url::fromRoute('<button>');
+    $url->setUrlGenerator($this->urlGenerator);
+
+    $result = $this->linkGenerator->generate('Test', $url);
+    $this->assertInstanceOf(GeneratedButton::class, $result);
+    $this->assertSame('<button type="button">Test</button>', (string) $result);
+  }
+
   /**
    * Tests the generate() method with an external URL.
    *
@@ -416,7 +437,7 @@ class LinkGeneratorTest extends UnitTestCase {
         'tag' => 'em',
       ],
     ], $result);
-    $this->assertTrue(strpos($result, '<em>HTML output</em>') !== FALSE);
+    $this->assertStringContainsString('<em>HTML output</em>', $result);
   }
 
   /**
@@ -431,8 +452,10 @@ class LinkGeneratorTest extends UnitTestCase {
         switch ($name) {
           case 'test_route_1':
             return (new GeneratedUrl())->setGeneratedUrl('/test-route-1');
+
           case 'test_route_3':
             return (new GeneratedUrl())->setGeneratedUrl('/test-route-3');
+
           case 'test_route_4':
             if ($parameters['object'] == '1') {
               return (new GeneratedUrl())->setGeneratedUrl('/test-route-4/1');
