@@ -146,9 +146,9 @@
     /**
      * Used to determine up or down direction from last mouse move.
      *
-     * @type {number}
+     * @type {?number}
      */
-    this.oldY = 0;
+    this.oldY = null;
 
     /**
      * Whether anything in the entire table has changed.
@@ -237,10 +237,10 @@
       // manually append 2 indentations in the first draggable row, measure
       // the offset, then remove.
       const indent = Drupal.theme('tableDragIndentation');
-      const testRow = $('<tr/>')
+      const testRow = $('<tr></tr>')
         .addClass('draggable')
         .appendTo(table);
-      const testCell = $('<td/>')
+      const testCell = $('<td></td>')
         .appendTo(testRow)
         .prepend(indent)
         .prepend(indent);
@@ -443,7 +443,7 @@
       $tables.find('.js-tabledrag-handle').css('display', '');
       // Reduce the colspan of any effected multi-span columns.
       $tables.find('.tabledrag-has-colspan').each(function decreaseColspan() {
-        this.colSpan = this.colSpan - 1;
+        this.colSpan -= -1;
       });
       // Change link text.
       $('.js-tabledrag-toggle-weight-wrapper').each(
@@ -483,7 +483,7 @@
       $tables.find('.js-tabledrag-handle').css('display', 'none');
       // Increase the colspan for any columns where it was previously reduced.
       $tables.find('.tabledrag-has-colspan').each(function increaseColspan() {
-        this.colSpan = this.colSpan + 1;
+        this.colSpan += 1;
       });
       // Change link text.
       $('.js-tabledrag-toggle-weight-wrapper').each(
@@ -817,7 +817,7 @@
      * @param {Drupal.tableDrag} self
      *   The drag handle.
      * @param {HTMLElement} item
-     *   The item that that is being dragged.
+     *   The item that is being dragged.
      */
     dragStart(event, self, item) {
       // Create a new dragObject recording the pointer information.
@@ -856,6 +856,10 @@
       if (self.oldRowElement) {
         $(self.oldRowElement).removeClass('drag-previous');
       }
+
+      // Set the initial y coordinate so the direction can be calculated in
+      // dragRow().
+      self.oldY = self.pointerCoords(event).y;
     },
 
     /**
@@ -1820,7 +1824,7 @@
        *   A string representing a DOM fragment.
        */
       tableDragCellItemsWrapper() {
-        return '<div class="tabledrag-cell-content"/>';
+        return '<div class="tabledrag-cell-content"></div>';
       },
 
       /**
@@ -1830,7 +1834,7 @@
        *   A string representing a DOM fragment.
        */
       tableDragCellContentWrapper() {
-        return '<div class="tabledrag-cell-content__item"/>';
+        return '<div class="tabledrag-cell-content__item"></div>';
       },
 
       /**
